/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalLine.h"
#include "HvMath.h"
#include "HvSignalRPole.h"
#include "HvControlRandom.h"
#include "HvControlCast.h"
#include "HvControlTabhead.h"
#include "HvControlDelay.h"
#include "HvTable.h"
#include "HvControlVar.h"
#include "HvSignalDel1.h"
#include "HvControlSystem.h"
#include "HvControlPack.h"
#include "HvControlSlice.h"
#include "HvControlBinop.h"
#include "HvSignalPhasor.h"
#include "HvControlUnop.h"
#include "HvSignalTabread.h"
#include "HvControlIf.h"
#include "HvSignalTabwrite.h"
#include "HvSignalVar.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_4gJVQYYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zbw6nRua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_xhMlgPjs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_BeBQWXEj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eu4ZStMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ym3uDaUs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_rczTNGkv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_e4HziIjw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TG03f8pU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g2QUpxBb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qSZB5DII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Q5y92qYW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_0oG67pxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_K1a7nPvS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_IodJ8R1r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Sfkgv2bv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vfnXjozu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ll5NEZFq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ly5rUWSf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0rnyJL8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TtZdLAhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XtzT39MF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ytJpwzjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_R8qDaBIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0xe50CwJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_j1J7PE8P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l6RoyYBI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t9yVcV6p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XfUoputc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aHuTCYAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GTzqK4U7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BGNB62t7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dVfpNvHu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xaYY6s38_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OdsBSZoF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j1JcfVNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4hIEQdmv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wAFoxYqD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O5XwSybf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SLn0bx3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LpJbzcwP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u0rHsiGp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D2urfxXH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BNDGTwDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pID1cwJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_28xkgDT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_N4Uzjg55_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ABRmPmHu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1SDH2PjD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EC8WvbqK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QZ5PJ9jh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jxwpq87e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_98ZFLQWa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yH8vbQtS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YWwY6kVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_15exIJUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NscNzoWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uguJMMvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OCB795Yq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dD3lj4f1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UbUDRBNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TI84Hvkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mwXMlE8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_36lXW6qD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_AVdAS6Li_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QkcrSUye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_2ADhlplZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_n4XJJv4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AQ07Wzsg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_FnHuTXQB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nkIqGIVy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4vkdTRp0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_va6GKY3F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OKQMT6vc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9jiewffE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vnTyz5rR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZUnKNsrd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bC3jAEt0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_VHNUpcyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DlVoXpom_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cUbGDuO6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_66UNRuIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sPL5hztK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_8pDtPPPE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_guWyVg9B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f9QnJIfe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IdkGpIQw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_shCGl4OT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Pr4182wD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JLpu3K77_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xsFMVrhX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rToy5fIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sPnQPqt2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mHaP2xGH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DintgxvO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sftBgHCS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hFyH8J7b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_1MzJEVP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uaWZChKu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RyWYYhSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oSioy4RR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CX7y5dPJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ej5Jp9Ha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_n6s9zB6H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DUGJEKDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sE6xYzih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FzCsXLkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9kQhgZaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5l2WVsRk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zTt3LsfO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_63dzpwrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pAEQLpSs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JdRE1FOU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W0nw2I2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mgEZeh48_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0oM2Hs5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_MwQcb610_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rHZdSoS3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xKhasjUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_flBywxs2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CKUtOVD9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dihycU3I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_vEDhi6Rh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lgT97wkE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qGjCbO15_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TmSgqJ48_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wXPwgp4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_knHn7eqV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ArDJd3A4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HJf3cDOp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vh7oernu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bXuVUHbp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dmIYJv3E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b3LgSsB3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wyWGZpZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_bkqdNuFv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CdiH7B7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YreIcpqT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TvCobsRN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pQ8WzMxh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1LAhkyZE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_N6lRVyoH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LmsHbmNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iwRQsw11_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TmG7fbpi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bUDW4VFj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TICcZhuL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xFdrIm2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vbx8dKzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BY2nC7Kk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RrvsRUdA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_orLmVQbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_teLBG4mf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9TvO6XQE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9yfStTvK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_g5zxFviS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FbZoSyK0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sgYsgubx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dv19qyGT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_cNkCOWWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_YYgapYIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hns1kfkR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XELuAYzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jCU7BPdj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WG2BLU9G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2xNzIaGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EbgtpfQx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3QFyFfvK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AYs6t4is_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_YcoQSbzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_yTrjeKmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_T7sgCj88_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_yxfcctM4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_OyoFPstG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3mdZGj2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jdf8Nhnk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2Z8BfDP7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2tSh0i4D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AiatWb87_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9Q1EAMK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HQ7onNKQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_koYyMGx3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_cq5wqCU9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qemwhIIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lCrwzMWn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_DXWoaflb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_1lDxc7X2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MIhUc3aD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i0gbdMDJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IsutIGwD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zbjfAelc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sdbTqmsr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WEuA9TRs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YvY1vgPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VnfVDer7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oRH1FC0X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DoBZbNQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bTRhzfZ1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_4Jfca7di_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_JsdBq0hM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m8jwjukJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8xdUANms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_msBW83no_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Dz0qmaAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KDzULgCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AA3DtuSV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_yDdv8NDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_3MqyQ3Ic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A8lfzEXW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LXV0i320_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DzGgnI8S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3eb1Xok9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_n1UBytL7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mVzzejFR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nnfOYEvA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JQaLa3sG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uRLoHHnD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fVELWqzq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GJOWPYkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YtI9UFlS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FHFZmOYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EXzgjIwo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_S1t03x3k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zOb6ycjj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bR5fB3SI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iNpQYc74_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FER5zByB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rWVrliwp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VZhkc25t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Cz2f2Z1Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ovBvcaqE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3Wr7aieP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_WTfIpkWE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_cN7vkwfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n7CuCdjr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C6W7aj2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A02Ghgda_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xBLhfyaN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GCjUKZz3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XS2SGQaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_S6dA0o4k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y46bO6Bw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8Ng7A0Ry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_alUUrjTT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hw9qNDt2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hbXRLznR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_MkzWsSW2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TGcvO5D4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V1B90lIh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uVYDjQQo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KGTUAslg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DUGG4hzn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8TvMsSwu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZAcd3uka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n60CbpQj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tvj0vOS7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nozwbkph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_siMuCCFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tWEHAW3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5MrJJmeW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uqOJ0u80_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FRQYETV9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hBxjXakN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GrOXOOcA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_GiYPFshh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_5dkr0VM0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6yHbllvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l2RwkR3x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aeTbjeuh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xlGPrLqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y12eZNb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_epA0DF7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_5hqF6Qbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H2I5CIsT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VQ2Wmu1p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pPIFiRJX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_eC8WAeg9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_AxMKF2k9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_vMdXOTR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kgHL7wcW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cjR3d3Gr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HeNzxhEk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FnlbCqst_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2WFKdkNJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YVLH3SJL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FwWBWsdJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zVe9SaeI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tnZ3R0pw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rHqEB7fm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XNuBai5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GbgUEbTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IFldoeC5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PxcgYYxQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5qa3Njj4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_WDHof3pu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZN26ASN0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_nfb93Hel_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_llIHknGv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xf2zUvRc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XaGRjxob_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ntbHOA0A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wejsxl8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1IWrhhy0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qR2CTonJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_iEuHz5ip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O2YNCM3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7wckEI9B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Wmo9EFSb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SFmBhoe8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bw45hEJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_HDOMTeYp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RpMeb8f2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eCBGoulC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TooEMthp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uHuvNHLc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_95rqRrDe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xi5ZGIIS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4hHgeszQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sUILQQrm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1pOWDi9A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nJRzR57U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CmcUV5Ba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PAxkgKYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KdxdNUDI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tdA34QYx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_iaIwWhuN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kfhmWrOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KSx2Z53i_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_pL8NeoC5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_F516Uqpi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dBSiWaW5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3zL2FqSV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G0qGILSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tGzSA8Uo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LBvZdBcj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Tkw1o5Ac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_fj1lZdUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wTuiB7iN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eYmixoRt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mW0vqLUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_um22hswr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2G8DLU2f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_RnN0W5Qf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LCxgjSiM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eX0htzkI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3kyb56wS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ScWGY4iQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y0JHKpRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xrsByR34_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n2oAmHN7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wwo3mej1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zxkbwfeo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rk8MZVhx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yIM65ckL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PXP0csZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jeOrtWOX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pCGR3vUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OWBEiKrM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_D5TgJW3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Xni2Z8wQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_iDz6a8Q2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_dKlOBRo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9QY42O67_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GVGRggWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jaTpergB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2YaY8Yl8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dpDQ3R0d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CaPKjuCe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Gwqtjw7X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9kcrLNps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_aamGGB9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3CK57A1A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_7Ik0lZjo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_spqoLhtO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_haIi5phZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mrTyzjM9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qO0DTGKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WipDfrZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_d1woP1HS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ozCQRa2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N8aJYI2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8EW6vDAB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4udw43pg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FQn3FFze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lFRA32OX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0OHVNLqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kORUFpVH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gAvmoMPb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_L5ef4xyj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QG9xtvyA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_cpEOJFKX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_knMn0Eak_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_AV6qeuQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_yguk0PG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ArFaJQcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2iGBceQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CLJxjN5c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rWoQHS72_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hiWTsA0x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_saUiLEl7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_jwI9Xa6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l2HJnGSz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_guPjZrYq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4xZCBs1H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4KzR9MHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_slVdgPrc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_VOnK3mhv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ta3ws88l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YxiRY8hy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_955OAG0c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1mNoe7Fs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MMoFUP2c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e29w4Kk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JtQ9aevW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V2xJwhBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wU52poua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KvkvSUha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gs5qscca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QkpMrLeU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3EdXkCod_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xpNlYWgg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_dPLg30SA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vjuWVpod_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DBlnray8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ImRkrhaq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iVs1nQBi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SxjxPBKJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zSUVpb3c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_80W1IioP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cJJpw5ct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pngzgPis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GAEOgI0W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ysskyK13_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_adWo5amP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WFIiVKuT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TEOnhomE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6nNjNe4U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nzogPsdD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rCUPVDmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Evvs4LfW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cSbz2AVe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MR4HIrKO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jaGBWKSN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F1xYnzDG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DcVDzXxH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H712xHEz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WgAHkgKl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FzKbJjTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xRzfKbT1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yc88O5w0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y6jrIbwo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BznefzsL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n1h4YNeR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_j4mUZ5kX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_MAXP30XF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_obb3bAXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q6lLSRJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rX81MUVy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xU2QLchf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xKOm0zWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fDOsPPEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_STC9ngh6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CTRtAvPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pDpSOC6L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_L392ELO7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_gv4W9GBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_zvCFYcll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6euSnaLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UsY72AFJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1AlPZXO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_TxYpHfKD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EGNPR0N3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_S5BtpJM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UYGTeM79_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_pwagoBsj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_kCJUpx5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DHiwTljY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iQWA9K8e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aWsKXu2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jTGDyNS2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OfC312kS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q7MiZrQg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_JR0nZVB1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aNn1SVvf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RdC7fN63_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PMSsThzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kreCbN1I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ovcNM0eC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_oGLyIP6x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7G8RH8VK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BQheJf0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iYoI5xp5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CkSphRvl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_unQvmGsd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B0EQEWk0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Sq5qvo8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IZMWLebC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PLcrYguT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K2UVoqvj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZUNeRilY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XgL7y4FC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_psc5VoWw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_p8tSM0P0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lTOktlsM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mBuuEEF6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_QS7uVPGy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ik9KiUqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BQfqAXFO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GOAJvMK3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lkVcmetA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_keztrPAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pjWDcGqw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_XxLN2JYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gQbbEBAX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5L0NQJL0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kTxmHFNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_S57y7ADP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lIhVQ8lu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vMmQbbqU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mUOSY5C0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6QuTKWZJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_AcdvJeQs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_LIexo4MG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VNobUAt1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tjQoGLW2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_26mE32bi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xquKf5Ps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1E0v02TO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IWuueMGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MkoAs2ef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CVwK3JSV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nNOE8Rmb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vJg0krm3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_32OmouW4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_d54lKCxX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dD6HUpsi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ss6myNPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nz40jdbn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pd23kr4Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f99Ua9W1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CjyGG9zE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4zy5UYaK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zr1PSpAC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cEXgc4ss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vjotDcve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z9Wuz7Fu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q9K7JYlT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RVRRcq4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nNKcxCvl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FfGytdZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LyqpKw1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gy5ikwOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lIOTJJij_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CoK6isnP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_93yD7eOZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7BNH55aX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VXSG8MyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x5sXQR9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sWkdVYUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GOaeReXA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9OK1hxp0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f7jnrxZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JtcYcVq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xd7hQOPd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jjaH4gJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MFuRtdV5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TxU0NbgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OAumasf5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TwUPTCf9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wxukpuHA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KmxNCXmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GsD3Fpdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RpG3cMQR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JkSt1k9a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jV2Bjrv4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h86OueuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9BERUQ6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ymbjjUXJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y0etEuyF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SCyEOrPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YBbSi8es_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oRVN8Cm1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rx8N8NAc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jrZMpkW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1udgLxMl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_N8oRy1d1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UmxbtSMQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GqyccCos_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TAihuQ2o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vYhXSovW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SbVJHtzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LfjHtJyj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VE4Ch99B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XHEabZlQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_O7sTwoqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CoAVDHp4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kSJEvwUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GKaMurlp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7w5DpbRm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GYtnhZZf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oiXnj4Bw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iHeah1DY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7aQ6oG4E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gUtIJKth_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mkrbxsGe_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_ERdIvyGD;
  SignalLine sLine_xfuVcpxL;
  SignalLine sLine_dy9qa5o0;
  SignalTabhead sTabhead_qZ6meuwX;
  SignalTabread sTabread_rAMXp1EY;
  SignalTabread sTabread_HsMZ05sY;
  SignalTabhead sTabhead_SAPMiBJB;
  SignalTabread sTabread_flSoxKp2;
  SignalTabread sTabread_tyQjS7ka;
  SignalTabwrite sTabwrite_rTjauolH;
  SignalRPole sRPole_R5MJW1ot;
  SignalDel1 sDel1_Vb64x7LZ;
  SignalTabread sTabread_oGLyIP6x;
  SignalTabwrite sTabwrite_Hb9zx3Ds;
  SignalTabread sTabread_guWyVg9B;
  SignalRPole sRPole_yLhijXIR;
  SignalLine sLine_gcmhCJGh;
  SignalLine sLine_3U3TA50p;
  SignalTabread sTabread_MkzWsSW2;
  SignalTabread sTabread_vMdXOTR5;
  SignalTabread sTabread_HDOMTeYp;
  SignalTabread sTabread_RnN0W5Qf;
  SignalTabread sTabread_VOnK3mhv;
  SignalTabread sTabread_haIi5phZ;
  SignalTabwrite sTabwrite_zd4xJu88;
  SignalTabwrite sTabwrite_X0zvk12g;
  SignalTabwrite sTabwrite_O41y9N0s;
  SignalTabwrite sTabwrite_Y0Yi1BAy;
  SignalTabwrite sTabwrite_92FFn8B7;
  SignalTabwrite sTabwrite_oAtZ59Fu;
  SignalTabread sTabread_n6s9zB6H;
  SignalRPole sRPole_kB7pyp57;
  SignalTabread sTabread_vEDhi6Rh;
  SignalRPole sRPole_hw2MmEKt;
  SignalTabread sTabread_N6lRVyoH;
  SignalRPole sRPole_DvTzBPfI;
  SignalTabwrite sTabwrite_5ueQZyas;
  SignalTabwrite sTabwrite_ZDs6rfmz;
  SignalTabwrite sTabwrite_1PE4jJf8;
  SignalTabwrite sTabwrite_aUIH03YJ;
  SignalLine sLine_OuJ1r92g;
  ControlVar cVar_4gJVQYYc;
  ControlVar cVar_zbw6nRua;
  ControlPack cPack_xhMlgPjs;
  ControlBinop cBinop_eu4ZStMP;
  ControlVar cVar_ym3uDaUs;
  ControlPack cPack_rczTNGkv;
  ControlVar cVar_e4HziIjw;
  ControlVar cVar_TG03f8pU;
  ControlDelay cDelay_Q5y92qYW;
  ControlDelay cDelay_0oG67pxx;
  ControlBinop cBinop_IodJ8R1r;
  HvTable hTable_Sfkgv2bv;
  ControlBinop cBinop_ll5NEZFq;
  ControlVar cVar_0xe50CwJ;
  ControlBinop cBinop_l6RoyYBI;
  ControlBinop cBinop_XfUoputc;
  SignalVarf sVarf_au2mqq4Z;
  SignalVarf sVarf_7VobTcI1;
  SignalVarf sVarf_S9IbsNIL;
  ControlVar cVar_BGNB62t7;
  ControlBinop cBinop_xaYY6s38;
  ControlBinop cBinop_j1JcfVNs;
  SignalVarf sVarf_WMfXXAGu;
  SignalVarf sVarf_Pw6XGGzx;
  SignalVarf sVarf_Bk38OOll;
  ControlBinop cBinop_4hIEQdmv;
  ControlBinop cBinop_wAFoxYqD;
  ControlBinop cBinop_LpJbzcwP;
  ControlBinop cBinop_u0rHsiGp;
  ControlBinop cBinop_D2urfxXH;
  ControlBinop cBinop_BNDGTwDt;
  ControlBinop cBinop_pID1cwJy;
  ControlBinop cBinop_QZ5PJ9jh;
  ControlBinop cBinop_Jxwpq87e;
  SignalVarf sVarf_m2D7eUJt;
  ControlVar cVar_98ZFLQWa;
  ControlBinop cBinop_15exIJUe;
  ControlBinop cBinop_NscNzoWr;
  ControlBinop cBinop_OCB795Yq;
  ControlBinop cBinop_dD3lj4f1;
  ControlBinop cBinop_UbUDRBNq;
  ControlBinop cBinop_TI84Hvkb;
  ControlBinop cBinop_mwXMlE8W;
  SignalVarf sVarf_wgDBY61G;
  ControlBinop cBinop_AVdAS6Li;
  ControlRandom cRandom_2ADhlplZ;
  ControlSlice cSlice_n4XJJv4F;
  ControlDelay cDelay_FnHuTXQB;
  ControlVar cVar_OKQMT6vc;
  ControlBinop cBinop_vnTyz5rR;
  ControlBinop cBinop_ZUnKNsrd;
  ControlBinop cBinop_bC3jAEt0;
  ControlTabhead cTabhead_VHNUpcyY;
  ControlVar cVar_66UNRuIJ;
  ControlDelay cDelay_sPL5hztK;
  ControlDelay cDelay_8pDtPPPE;
  ControlBinop cBinop_f9QnJIfe;
  ControlBinop cBinop_IdkGpIQw;
  ControlBinop cBinop_shCGl4OT;
  ControlBinop cBinop_sPnQPqt2;
  ControlBinop cBinop_DintgxvO;
  ControlBinop cBinop_sftBgHCS;
  ControlTabhead cTabhead_1MzJEVP6;
  ControlVar cVar_oSioy4RR;
  ControlDelay cDelay_CX7y5dPJ;
  ControlDelay cDelay_ej5Jp9Ha;
  ControlBinop cBinop_DUGJEKDw;
  ControlBinop cBinop_sE6xYzih;
  ControlBinop cBinop_FzCsXLkb;
  ControlBinop cBinop_pAEQLpSs;
  ControlBinop cBinop_W0nw2I2S;
  ControlBinop cBinop_mgEZeh48;
  ControlTabhead cTabhead_MwQcb610;
  ControlVar cVar_flBywxs2;
  ControlDelay cDelay_CKUtOVD9;
  ControlDelay cDelay_dihycU3I;
  ControlBinop cBinop_lgT97wkE;
  ControlBinop cBinop_qGjCbO15;
  ControlBinop cBinop_TmSgqJ48;
  ControlBinop cBinop_vh7oernu;
  ControlBinop cBinop_dmIYJv3E;
  ControlBinop cBinop_b3LgSsB3;
  ControlTabhead cTabhead_bkqdNuFv;
  ControlVar cVar_TvCobsRN;
  ControlDelay cDelay_pQ8WzMxh;
  ControlDelay cDelay_1LAhkyZE;
  ControlBinop cBinop_LmsHbmNs;
  ControlBinop cBinop_iwRQsw11;
  ControlBinop cBinop_TmG7fbpi;
  ControlBinop cBinop_BY2nC7Kk;
  ControlBinop cBinop_orLmVQbM;
  ControlBinop cBinop_teLBG4mf;
  ControlDelay cDelay_FbZoSyK0;
  ControlDelay cDelay_sgYsgubx;
  ControlBinop cBinop_cNkCOWWp;
  HvTable hTable_YYgapYIQ;
  ControlBinop cBinop_XELuAYzp;
  ControlDelay cDelay_YcoQSbzb;
  ControlDelay cDelay_yTrjeKmD;
  ControlBinop cBinop_yxfcctM4;
  HvTable hTable_OyoFPstG;
  ControlBinop cBinop_Jdf8Nhnk;
  ControlDelay cDelay_cq5wqCU9;
  ControlDelay cDelay_qemwhIIy;
  ControlBinop cBinop_DXWoaflb;
  HvTable hTable_1lDxc7X2;
  ControlBinop cBinop_i0gbdMDJ;
  ControlDelay cDelay_oRH1FC0X;
  ControlDelay cDelay_DoBZbNQl;
  ControlBinop cBinop_4Jfca7di;
  HvTable hTable_JsdBq0hM;
  ControlBinop cBinop_8xdUANms;
  ControlPack cPack_yDdv8NDm;
  ControlPack cPack_3MqyQ3Ic;
  ControlBinop cBinop_A8lfzEXW;
  ControlBinop cBinop_LXV0i320;
  ControlVar cVar_DzGgnI8S;
  ControlBinop cBinop_mVzzejFR;
  ControlBinop cBinop_nnfOYEvA;
  SignalVarf sVarf_Sj6KzPbl;
  ControlBinop cBinop_uRLoHHnD;
  ControlBinop cBinop_fVELWqzq;
  ControlBinop cBinop_GJOWPYkT;
  SignalVarf sVarf_MgMfgY4V;
  ControlVar cVar_YtI9UFlS;
  ControlVar cVar_FHFZmOYJ;
  ControlVar cVar_EXzgjIwo;
  ControlVar cVar_S1t03x3k;
  ControlIf cIf_zOb6ycjj;
  ControlBinop cBinop_bR5fB3SI;
  ControlBinop cBinop_iNpQYc74;
  ControlBinop cBinop_FER5zByB;
  ControlDelay cDelay_Cz2f2Z1Q;
  ControlDelay cDelay_ovBvcaqE;
  ControlBinop cBinop_WTfIpkWE;
  HvTable hTable_cN7vkwfD;
  ControlBinop cBinop_C6W7aj2z;
  ControlTabhead cTabhead_S6dA0o4k;
  ControlVar cVar_alUUrjTT;
  ControlDelay cDelay_hw9qNDt2;
  ControlDelay cDelay_hbXRLznR;
  ControlBinop cBinop_TGcvO5D4;
  ControlBinop cBinop_V1B90lIh;
  ControlBinop cBinop_uVYDjQQo;
  ControlBinop cBinop_n60CbpQj;
  ControlBinop cBinop_Nozwbkph;
  ControlBinop cBinop_siMuCCFN;
  ControlDelay cDelay_FRQYETV9;
  ControlDelay cDelay_hBxjXakN;
  ControlBinop cBinop_GiYPFshh;
  HvTable hTable_5dkr0VM0;
  ControlBinop cBinop_l2RwkR3x;
  ControlTabhead cTabhead_5hqF6Qbl;
  ControlVar cVar_pPIFiRJX;
  ControlDelay cDelay_eC8WAeg9;
  ControlDelay cDelay_AxMKF2k9;
  ControlBinop cBinop_kgHL7wcW;
  ControlBinop cBinop_cjR3d3Gr;
  ControlBinop cBinop_HeNzxhEk;
  ControlBinop cBinop_zVe9SaeI;
  ControlBinop cBinop_rHqEB7fm;
  ControlBinop cBinop_XNuBai5V;
  ControlDelay cDelay_5qa3Njj4;
  ControlDelay cDelay_WDHof3pu;
  ControlBinop cBinop_nfb93Hel;
  HvTable hTable_llIHknGv;
  ControlBinop cBinop_XaGRjxob;
  ControlTabhead cTabhead_iEuHz5ip;
  ControlVar cVar_Wmo9EFSb;
  ControlDelay cDelay_SFmBhoe8;
  ControlDelay cDelay_bw45hEJT;
  ControlBinop cBinop_RpMeb8f2;
  ControlBinop cBinop_eCBGoulC;
  ControlBinop cBinop_TooEMthp;
  ControlBinop cBinop_sUILQQrm;
  ControlBinop cBinop_nJRzR57U;
  ControlBinop cBinop_CmcUV5Ba;
  ControlDelay cDelay_iaIwWhuN;
  ControlDelay cDelay_kfhmWrOB;
  ControlBinop cBinop_pL8NeoC5;
  HvTable hTable_F516Uqpi;
  ControlBinop cBinop_3zL2FqSV;
  ControlTabhead cTabhead_fj1lZdUQ;
  ControlVar cVar_mW0vqLUQ;
  ControlDelay cDelay_um22hswr;
  ControlDelay cDelay_2G8DLU2f;
  ControlBinop cBinop_LCxgjSiM;
  ControlBinop cBinop_eX0htzkI;
  ControlBinop cBinop_3kyb56wS;
  ControlBinop cBinop_wwo3mej1;
  ControlBinop cBinop_Rk8MZVhx;
  ControlBinop cBinop_yIM65ckL;
  ControlDelay cDelay_OWBEiKrM;
  ControlDelay cDelay_D5TgJW3e;
  ControlBinop cBinop_iDz6a8Q2;
  HvTable hTable_dKlOBRo3;
  ControlBinop cBinop_GVGRggWx;
  ControlTabhead cTabhead_Gwqtjw7X;
  ControlVar cVar_3CK57A1A;
  ControlDelay cDelay_7Ik0lZjo;
  ControlDelay cDelay_spqoLhtO;
  ControlBinop cBinop_mrTyzjM9;
  ControlBinop cBinop_qO0DTGKM;
  ControlBinop cBinop_WipDfrZC;
  ControlBinop cBinop_4udw43pg;
  ControlBinop cBinop_lFRA32OX;
  ControlBinop cBinop_0OHVNLqd;
  ControlDelay cDelay_QG9xtvyA;
  ControlDelay cDelay_cpEOJFKX;
  ControlBinop cBinop_AV6qeuQS;
  HvTable hTable_yguk0PG0;
  ControlBinop cBinop_2iGBceQy;
  ControlTabhead cTabhead_jwI9Xa6u;
  ControlVar cVar_4xZCBs1H;
  ControlDelay cDelay_4KzR9MHg;
  ControlDelay cDelay_slVdgPrc;
  ControlBinop cBinop_ta3ws88l;
  ControlBinop cBinop_YxiRY8hy;
  ControlBinop cBinop_955OAG0c;
  ControlBinop cBinop_V2xJwhBO;
  ControlBinop cBinop_KvkvSUha;
  ControlBinop cBinop_gs5qscca;
  ControlVar cVar_3EdXkCod;
  ControlVar cVar_xpNlYWgg;
  ControlPack cPack_dPLg30SA;
  ControlVar cVar_vjuWVpod;
  ControlBinop cBinop_iVs1nQBi;
  ControlBinop cBinop_SxjxPBKJ;
  SignalVarf sVarf_9Ase1ZHW;
  ControlBinop cBinop_80W1IioP;
  ControlBinop cBinop_cJJpw5ct;
  ControlBinop cBinop_pngzgPis;
  SignalVarf sVarf_zosRLRdY;
  ControlVar cVar_GAEOgI0W;
  ControlBinop cBinop_WFIiVKuT;
  ControlBinop cBinop_TEOnhomE;
  SignalVarf sVarf_ThuXaZPy;
  ControlBinop cBinop_nzogPsdD;
  ControlBinop cBinop_rCUPVDmI;
  ControlBinop cBinop_Evvs4LfW;
  SignalVarf sVarf_o59suLKx;
  ControlVar cVar_cSbz2AVe;
  ControlBinop cBinop_F1xYnzDG;
  ControlBinop cBinop_DcVDzXxH;
  SignalVarf sVarf_XwL3bbJ5;
  ControlBinop cBinop_WgAHkgKl;
  ControlBinop cBinop_FzKbJjTY;
  ControlBinop cBinop_xRzfKbT1;
  SignalVarf sVarf_CwFhWOxb;
  ControlBinop cBinop_Yc88O5w0;
  ControlBinop cBinop_BznefzsL;
  ControlBinop cBinop_n1h4YNeR;
  ControlDelay cDelay_MAXP30XF;
  ControlVar cVar_xU2QLchf;
  ControlBinop cBinop_fDOsPPEc;
  ControlBinop cBinop_STC9ngh6;
  ControlBinop cBinop_CTRtAvPN;
  ControlVar cVar_pDpSOC6L;
  ControlVar cVar_L392ELO7;
  ControlIf cIf_6euSnaLM;
  ControlBinop cBinop_UsY72AFJ;
  ControlDelay cDelay_EGNPR0N3;
  ControlDelay cDelay_S5BtpJM7;
  ControlBinop cBinop_pwagoBsj;
  HvTable hTable_kCJUpx5R;
  ControlBinop cBinop_iQWA9K8e;
  ControlTabhead cTabhead_JR0nZVB1;
  ControlVar cVar_PMSsThzv;
  ControlDelay cDelay_kreCbN1I;
  ControlDelay cDelay_ovcNM0eC;
  ControlBinop cBinop_7G8RH8VK;
  ControlBinop cBinop_BQheJf0L;
  ControlBinop cBinop_iYoI5xp5;
  ControlBinop cBinop_IZMWLebC;
  ControlBinop cBinop_K2UVoqvj;
  ControlBinop cBinop_ZUNeRilY;
  ControlVar cVar_lTOktlsM;
  ControlVar cVar_ik9KiUqm;
  ControlVar cVar_BQfqAXFO;
  ControlVar cVar_GOAJvMK3;
  ControlVar cVar_lkVcmetA;
  ControlVar cVar_keztrPAf;
  ControlIf cIf_gQbbEBAX;
  ControlBinop cBinop_5L0NQJL0;
  ControlVar cVar_kTxmHFNq;
  ControlIf cIf_vMmQbbqU;
  ControlBinop cBinop_mUOSY5C0;
  ControlSlice cSlice_AcdvJeQs;
  ControlSlice cSlice_LIexo4MG;
  ControlVar cVar_VNobUAt1;
  ControlIf cIf_tjQoGLW2;
  ControlBinop cBinop_1E0v02TO;
  ControlIf cIf_CVwK3JSV;
  ControlIf cIf_nNOE8Rmb;
  ControlIf cIf_vJg0krm3;
  ControlIf cIf_32OmouW4;
  ControlIf cIf_d54lKCxX;
  SignalVarf sVarf_lBraqtum;
  ControlBinop cBinop_f99Ua9W1;
  ControlBinop cBinop_CjyGG9zE;
  ControlBinop cBinop_Zr1PSpAC;
  ControlBinop cBinop_cEXgc4ss;
  SignalVarf sVarf_alBIFmt2;
  ControlBinop cBinop_Z9Wuz7Fu;
  ControlBinop cBinop_q9K7JYlT;
  SignalVarf sVarf_Xtzp7OS4;
  SignalVarf sVarf_nZPc1cJP;
  ControlBinop cBinop_gy5ikwOB;
  ControlBinop cBinop_lIOTJJij;
  ControlBinop cBinop_CoK6isnP;
  ControlBinop cBinop_93yD7eOZ;
  ControlBinop cBinop_VXSG8MyC;
  ControlBinop cBinop_x5sXQR9T;
  ControlBinop cBinop_sWkdVYUe;
  ControlBinop cBinop_GOaeReXA;
  ControlBinop cBinop_f7jnrxZY;
  ControlBinop cBinop_JtcYcVq1;
  ControlBinop cBinop_Xd7hQOPd;
  ControlBinop cBinop_jV2Bjrv4;
  ControlBinop cBinop_h86OueuU;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
