/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_ERdIvyGD, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_xfuVcpxL);
  numBytes += sLine_init(&sLine_dy9qa5o0);
  numBytes += sTabhead_init(&sTabhead_qZ6meuwX, &hTable_Sfkgv2bv);
  numBytes += sTabread_init(&sTabread_rAMXp1EY, &hTable_Sfkgv2bv, false);
  numBytes += sTabread_init(&sTabread_HsMZ05sY, &hTable_Sfkgv2bv, false);
  numBytes += sTabhead_init(&sTabhead_SAPMiBJB, &hTable_Sfkgv2bv);
  numBytes += sTabread_init(&sTabread_flSoxKp2, &hTable_Sfkgv2bv, false);
  numBytes += sTabread_init(&sTabread_tyQjS7ka, &hTable_Sfkgv2bv, false);
  numBytes += sTabwrite_init(&sTabwrite_rTjauolH, &hTable_Sfkgv2bv);
  numBytes += sRPole_init(&sRPole_R5MJW1ot);
  numBytes += sDel1_init(&sDel1_Vb64x7LZ);
  numBytes += sTabread_init(&sTabread_oGLyIP6x, &hTable_kCJUpx5R, true);
  numBytes += sTabwrite_init(&sTabwrite_Hb9zx3Ds, &hTable_kCJUpx5R);
  numBytes += sTabread_init(&sTabread_guWyVg9B, &hTable_YYgapYIQ, true);
  numBytes += sRPole_init(&sRPole_yLhijXIR);
  numBytes += sLine_init(&sLine_gcmhCJGh);
  numBytes += sLine_init(&sLine_3U3TA50p);
  numBytes += sTabread_init(&sTabread_MkzWsSW2, &hTable_cN7vkwfD, true);
  numBytes += sTabread_init(&sTabread_vMdXOTR5, &hTable_5dkr0VM0, true);
  numBytes += sTabread_init(&sTabread_HDOMTeYp, &hTable_llIHknGv, true);
  numBytes += sTabread_init(&sTabread_RnN0W5Qf, &hTable_F516Uqpi, true);
  numBytes += sTabread_init(&sTabread_VOnK3mhv, &hTable_yguk0PG0, true);
  numBytes += sTabread_init(&sTabread_haIi5phZ, &hTable_dKlOBRo3, true);
  numBytes += sTabwrite_init(&sTabwrite_zd4xJu88, &hTable_cN7vkwfD);
  numBytes += sTabwrite_init(&sTabwrite_X0zvk12g, &hTable_5dkr0VM0);
  numBytes += sTabwrite_init(&sTabwrite_O41y9N0s, &hTable_llIHknGv);
  numBytes += sTabwrite_init(&sTabwrite_Y0Yi1BAy, &hTable_F516Uqpi);
  numBytes += sTabwrite_init(&sTabwrite_92FFn8B7, &hTable_dKlOBRo3);
  numBytes += sTabwrite_init(&sTabwrite_oAtZ59Fu, &hTable_yguk0PG0);
  numBytes += sTabread_init(&sTabread_n6s9zB6H, &hTable_OyoFPstG, true);
  numBytes += sRPole_init(&sRPole_kB7pyp57);
  numBytes += sTabread_init(&sTabread_vEDhi6Rh, &hTable_1lDxc7X2, true);
  numBytes += sRPole_init(&sRPole_hw2MmEKt);
  numBytes += sTabread_init(&sTabread_N6lRVyoH, &hTable_JsdBq0hM, true);
  numBytes += sRPole_init(&sRPole_DvTzBPfI);
  numBytes += sTabwrite_init(&sTabwrite_5ueQZyas, &hTable_YYgapYIQ);
  numBytes += sTabwrite_init(&sTabwrite_ZDs6rfmz, &hTable_OyoFPstG);
  numBytes += sTabwrite_init(&sTabwrite_1PE4jJf8, &hTable_1lDxc7X2);
  numBytes += sTabwrite_init(&sTabwrite_aUIH03YJ, &hTable_JsdBq0hM);
  numBytes += sLine_init(&sLine_OuJ1r92g);
  numBytes += cVar_init_f(&cVar_4gJVQYYc, 0.0f);
  numBytes += cVar_init_f(&cVar_zbw6nRua, 0.0f);
  numBytes += cPack_init(&cPack_xhMlgPjs, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_ym3uDaUs, 0.0f);
  numBytes += cPack_init(&cPack_rczTNGkv, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_e4HziIjw, 0.0f);
  numBytes += cVar_init_f(&cVar_TG03f8pU, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Q5y92qYW, 0.0f);
  numBytes += cDelay_init(this, &cDelay_0oG67pxx, 0.0f);
  numBytes += hTable_init(&hTable_Sfkgv2bv, 256);
  numBytes += cVar_init_s(&cVar_0xe50CwJ, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_au2mqq4Z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7VobTcI1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_S9IbsNIL, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_BGNB62t7, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_WMfXXAGu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Pw6XGGzx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bk38OOll, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_4hIEQdmv, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_m2D7eUJt, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_98ZFLQWa, 0.0f);
  numBytes += cBinop_init(&cBinop_mwXMlE8W, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_wgDBY61G, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_2ADhlplZ, 1390652401);
  numBytes += cSlice_init(&cSlice_n4XJJv4F, 1, 1);
  numBytes += cDelay_init(this, &cDelay_FnHuTXQB, 0.0f);
  numBytes += cVar_init_f(&cVar_OKQMT6vc, 5.0f);
  numBytes += cBinop_init(&cBinop_bC3jAEt0, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_VHNUpcyY, &hTable_YYgapYIQ);
  numBytes += cVar_init_s(&cVar_66UNRuIJ, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_sPL5hztK, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_8pDtPPPE, 0.0f);
  numBytes += cBinop_init(&cBinop_f9QnJIfe, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_shCGl4OT, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_sPnQPqt2, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_sftBgHCS, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_1MzJEVP6, &hTable_OyoFPstG);
  numBytes += cVar_init_s(&cVar_oSioy4RR, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_CX7y5dPJ, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_ej5Jp9Ha, 0.0f);
  numBytes += cBinop_init(&cBinop_DUGJEKDw, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_FzCsXLkb, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_pAEQLpSs, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_mgEZeh48, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_MwQcb610, &hTable_1lDxc7X2);
  numBytes += cVar_init_s(&cVar_flBywxs2, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_CKUtOVD9, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_dihycU3I, 0.0f);
  numBytes += cBinop_init(&cBinop_lgT97wkE, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_TmSgqJ48, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_vh7oernu, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_b3LgSsB3, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_bkqdNuFv, &hTable_JsdBq0hM);
  numBytes += cVar_init_s(&cVar_TvCobsRN, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_pQ8WzMxh, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_1LAhkyZE, 0.0f);
  numBytes += cBinop_init(&cBinop_LmsHbmNs, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_TmG7fbpi, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_BY2nC7Kk, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_teLBG4mf, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_FbZoSyK0, 0.0f);
  numBytes += cDelay_init(this, &cDelay_sgYsgubx, 0.0f);
  numBytes += hTable_init(&hTable_YYgapYIQ, 256);
  numBytes += cDelay_init(this, &cDelay_YcoQSbzb, 0.0f);
  numBytes += cDelay_init(this, &cDelay_yTrjeKmD, 0.0f);
  numBytes += hTable_init(&hTable_OyoFPstG, 256);
  numBytes += cDelay_init(this, &cDelay_cq5wqCU9, 0.0f);
  numBytes += cDelay_init(this, &cDelay_qemwhIIy, 0.0f);
  numBytes += hTable_init(&hTable_1lDxc7X2, 256);
  numBytes += cDelay_init(this, &cDelay_oRH1FC0X, 0.0f);
  numBytes += cDelay_init(this, &cDelay_DoBZbNQl, 0.0f);
  numBytes += hTable_init(&hTable_JsdBq0hM, 256);
  numBytes += cPack_init(&cPack_yDdv8NDm, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_3MqyQ3Ic, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_DzGgnI8S, 22050.0f);
  numBytes += cBinop_init(&cBinop_mVzzejFR, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Sj6KzPbl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MgMfgY4V, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_YtI9UFlS, 0.0f);
  numBytes += cVar_init_f(&cVar_FHFZmOYJ, 0.0f);
  numBytes += cVar_init_f(&cVar_EXzgjIwo, 0.0f);
  numBytes += cVar_init_f(&cVar_S1t03x3k, 0.0f);
  numBytes += cIf_init(&cIf_zOb6ycjj, false);
  numBytes += cDelay_init(this, &cDelay_Cz2f2Z1Q, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ovBvcaqE, 0.0f);
  numBytes += hTable_init(&hTable_cN7vkwfD, 256);
  numBytes += cTabhead_init(&cTabhead_S6dA0o4k, &hTable_cN7vkwfD);
  numBytes += cVar_init_s(&cVar_alUUrjTT, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_hw9qNDt2, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_hbXRLznR, 0.0f);
  numBytes += cBinop_init(&cBinop_TGcvO5D4, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_uVYDjQQo, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_n60CbpQj, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_siMuCCFN, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_FRQYETV9, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hBxjXakN, 0.0f);
  numBytes += hTable_init(&hTable_5dkr0VM0, 256);
  numBytes += cTabhead_init(&cTabhead_5hqF6Qbl, &hTable_5dkr0VM0);
  numBytes += cVar_init_s(&cVar_pPIFiRJX, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_eC8WAeg9, 25.796f);
  numBytes += cDelay_init(this, &cDelay_AxMKF2k9, 0.0f);
  numBytes += cBinop_init(&cBinop_kgHL7wcW, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_HeNzxhEk, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_zVe9SaeI, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_XNuBai5V, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_5qa3Njj4, 0.0f);
  numBytes += cDelay_init(this, &cDelay_WDHof3pu, 0.0f);
  numBytes += hTable_init(&hTable_llIHknGv, 256);
  numBytes += cTabhead_init(&cTabhead_iEuHz5ip, &hTable_llIHknGv);
  numBytes += cVar_init_s(&cVar_Wmo9EFSb, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_SFmBhoe8, 19.392f);
  numBytes += cDelay_init(this, &cDelay_bw45hEJT, 0.0f);
  numBytes += cBinop_init(&cBinop_RpMeb8f2, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_TooEMthp, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_sUILQQrm, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_CmcUV5Ba, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_iaIwWhuN, 0.0f);
  numBytes += cDelay_init(this, &cDelay_kfhmWrOB, 0.0f);
  numBytes += hTable_init(&hTable_F516Uqpi, 256);
  numBytes += cTabhead_init(&cTabhead_fj1lZdUQ, &hTable_F516Uqpi);
  numBytes += cVar_init_s(&cVar_mW0vqLUQ, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_um22hswr, 16.364f);
  numBytes += cDelay_init(this, &cDelay_2G8DLU2f, 0.0f);
  numBytes += cBinop_init(&cBinop_LCxgjSiM, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_3kyb56wS, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_wwo3mej1, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_yIM65ckL, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_OWBEiKrM, 0.0f);
  numBytes += cDelay_init(this, &cDelay_D5TgJW3e, 0.0f);
  numBytes += hTable_init(&hTable_dKlOBRo3, 256);
  numBytes += cTabhead_init(&cTabhead_Gwqtjw7X, &hTable_dKlOBRo3);
  numBytes += cVar_init_s(&cVar_3CK57A1A, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_7Ik0lZjo, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_spqoLhtO, 0.0f);
  numBytes += cBinop_init(&cBinop_mrTyzjM9, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_WipDfrZC, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_4udw43pg, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_0OHVNLqd, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_QG9xtvyA, 0.0f);
  numBytes += cDelay_init(this, &cDelay_cpEOJFKX, 0.0f);
  numBytes += hTable_init(&hTable_yguk0PG0, 256);
  numBytes += cTabhead_init(&cTabhead_jwI9Xa6u, &hTable_yguk0PG0);
  numBytes += cVar_init_s(&cVar_4xZCBs1H, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_4KzR9MHg, 7.645f);
  numBytes += cDelay_init(this, &cDelay_slVdgPrc, 0.0f);
  numBytes += cBinop_init(&cBinop_ta3ws88l, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_955OAG0c, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_V2xJwhBO, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_gs5qscca, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_3EdXkCod, 0.0f);
  numBytes += cVar_init_f(&cVar_xpNlYWgg, 0.0f);
  numBytes += cPack_init(&cPack_dPLg30SA, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_vjuWVpod, 22050.0f);
  numBytes += cBinop_init(&cBinop_iVs1nQBi, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_9Ase1ZHW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zosRLRdY, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_GAEOgI0W, 22050.0f);
  numBytes += cBinop_init(&cBinop_WFIiVKuT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ThuXaZPy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o59suLKx, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_cSbz2AVe, 22050.0f);
  numBytes += cBinop_init(&cBinop_F1xYnzDG, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_XwL3bbJ5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CwFhWOxb, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_MAXP30XF, 0.0f);
  numBytes += cVar_init_f(&cVar_xU2QLchf, 1000.0f);
  numBytes += cBinop_init(&cBinop_CTRtAvPN, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_pDpSOC6L, 0.0f);
  numBytes += cVar_init_f(&cVar_L392ELO7, 0.0f);
  numBytes += cIf_init(&cIf_6euSnaLM, false);
  numBytes += cDelay_init(this, &cDelay_EGNPR0N3, 0.0f);
  numBytes += cDelay_init(this, &cDelay_S5BtpJM7, 0.0f);
  numBytes += hTable_init(&hTable_kCJUpx5R, 256);
  numBytes += cTabhead_init(&cTabhead_JR0nZVB1, &hTable_kCJUpx5R);
  numBytes += cVar_init_s(&cVar_PMSsThzv, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_kreCbN1I, 150.0f);
  numBytes += cDelay_init(this, &cDelay_ovcNM0eC, 0.0f);
  numBytes += cBinop_init(&cBinop_7G8RH8VK, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_iYoI5xp5, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_IZMWLebC, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_ZUNeRilY, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_lTOktlsM, 0.0f);
  numBytes += cVar_init_f(&cVar_ik9KiUqm, 0.0f);
  numBytes += cVar_init_f(&cVar_BQfqAXFO, 0.0f);
  numBytes += cVar_init_f(&cVar_GOAJvMK3, 0.0f);
  numBytes += cVar_init_f(&cVar_lkVcmetA, 0.0f);
  numBytes += cVar_init_f(&cVar_keztrPAf, 0.0f);
  numBytes += cIf_init(&cIf_gQbbEBAX, false);
  numBytes += cVar_init_f(&cVar_kTxmHFNq, 0.0f);
  numBytes += cIf_init(&cIf_vMmQbbqU, false);
  numBytes += cSlice_init(&cSlice_AcdvJeQs, 1, -1);
  numBytes += cSlice_init(&cSlice_LIexo4MG, 1, -1);
  numBytes += cVar_init_f(&cVar_VNobUAt1, 0.0f);
  numBytes += cIf_init(&cIf_tjQoGLW2, false);
  numBytes += cBinop_init(&cBinop_1E0v02TO, 0.0f); // __neq
  numBytes += cIf_init(&cIf_CVwK3JSV, false);
  numBytes += cIf_init(&cIf_nNOE8Rmb, false);
  numBytes += cIf_init(&cIf_vJg0krm3, false);
  numBytes += cIf_init(&cIf_32OmouW4, true);
  numBytes += cIf_init(&cIf_d54lKCxX, false);
  numBytes += sVarf_init(&sVarf_lBraqtum, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_Zr1PSpAC, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_alBIFmt2, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_Z9Wuz7Fu, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_q9K7JYlT, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_Xtzp7OS4, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nZPc1cJP, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_lIOTJJij, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_f7jnrxZY, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_JtcYcVq1, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_Xd7hQOPd, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_jV2Bjrv4, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_h86OueuU, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_xhMlgPjs);
  cPack_free(&cPack_rczTNGkv);
  hTable_free(&hTable_Sfkgv2bv);
  hTable_free(&hTable_YYgapYIQ);
  hTable_free(&hTable_OyoFPstG);
  hTable_free(&hTable_1lDxc7X2);
  hTable_free(&hTable_JsdBq0hM);
  cPack_free(&cPack_yDdv8NDm);
  cPack_free(&cPack_3MqyQ3Ic);
  hTable_free(&hTable_cN7vkwfD);
  hTable_free(&hTable_5dkr0VM0);
  hTable_free(&hTable_llIHknGv);
  hTable_free(&hTable_F516Uqpi);
  hTable_free(&hTable_dKlOBRo3);
  hTable_free(&hTable_yguk0PG0);
  cPack_free(&cPack_dPLg30SA);
  hTable_free(&hTable_kCJUpx5R);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_Sfkgv2bv; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_YYgapYIQ; // del-1052-del1
    case 0xA2AC524D: return &hTable_OyoFPstG; // del-1052-del2
    case 0xE36A35B: return &hTable_1lDxc7X2; // del-1052-del3
    case 0x48CE0509: return &hTable_JsdBq0hM; // del-1052-del4
    case 0xE34D6E72: return &hTable_cN7vkwfD; // del-1052-ref1
    case 0x6A1027AB: return &hTable_5dkr0VM0; // del-1052-ref2
    case 0xA37C6D49: return &hTable_llIHknGv; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_F516Uqpi; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_dKlOBRo3; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_yguk0PG0; // del-1052-ref5
    case 0xED65564F: return &hTable_kCJUpx5R; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rx8N8NAc_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_N8oRy1d1_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1udgLxMl_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mkrbxsGe_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jrZMpkW9_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UmxbtSMQ_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GqyccCos_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LfjHtJyj_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SbVJHtzW_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VE4Ch99B_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XHEabZlQ_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TAihuQ2o_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vYhXSovW_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iHeah1DY_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oiXnj4Bw_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GYtnhZZf_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7w5DpbRm_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gUtIJKth_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7aQ6oG4E_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CoAVDHp4_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O7sTwoqz_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GKaMurlp_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kSJEvwUi_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oRVN8Cm1_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_4gJVQYYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_u0rHsiGp_sendMessage);
}

void Heavy_ChaffVerb::cVar_zbw6nRua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_pID1cwJy_sendMessage);
}

void Heavy_ChaffVerb::cPack_xhMlgPjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_xfuVcpxL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_BeBQWXEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ym3uDaUs, 0, m, &cVar_ym3uDaUs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eu4ZStMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_BeBQWXEj_sendMessage);
}

void Heavy_ChaffVerb::cVar_ym3uDaUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LpJbzcwP_sendMessage);
}

void Heavy_ChaffVerb::cPack_rczTNGkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_dy9qa5o0, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_e4HziIjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_BNDGTwDt_sendMessage);
}

void Heavy_ChaffVerb::cVar_TG03f8pU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_ERdIvyGD, 0, m);
}

void Heavy_ChaffVerb::cMsg_g2QUpxBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qSZB5DII_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qSZB5DII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ll5NEZFq_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Q5y92qYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q5y92qYW, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0oG67pxx, 0, m, &cDelay_0oG67pxx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q5y92qYW, 0, m, &cDelay_Q5y92qYW_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rTjauolH, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_0oG67pxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0oG67pxx, m);
  cMsg_ly5rUWSf_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_K1a7nPvS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_XtzT39MF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_IodJ8R1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vfnXjozu_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Sfkgv2bv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TtZdLAhl_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q5y92qYW, 2, m, &cDelay_Q5y92qYW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0rnyJL8f_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vfnXjozu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Sfkgv2bv, 0, m, &hTable_Sfkgv2bv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ll5NEZFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_IodJ8R1r_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ly5rUWSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Sfkgv2bv, 0, m, &hTable_Sfkgv2bv_sendMessage);
}

void Heavy_ChaffVerb::cCast_0rnyJL8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q5y92qYW, 0, m, &cDelay_Q5y92qYW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TtZdLAhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_0oG67pxx, 2, m, &cDelay_0oG67pxx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XtzT39MF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rTjauolH, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_ytJpwzjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_R8qDaBIH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_R8qDaBIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_l6RoyYBI_sendMessage);
}

void Heavy_ChaffVerb::cVar_0xe50CwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t9yVcV6p_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_j1J7PE8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_XfUoputc_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_au2mqq4Z, m);
}

void Heavy_ChaffVerb::cBinop_l6RoyYBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7VobTcI1, m);
}

void Heavy_ChaffVerb::cMsg_t9yVcV6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_j1J7PE8P_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XfUoputc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_S9IbsNIL, m);
}

void Heavy_ChaffVerb::cMsg_aHuTCYAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GTzqK4U7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_GTzqK4U7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xaYY6s38_sendMessage);
}

void Heavy_ChaffVerb::cVar_BGNB62t7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OdsBSZoF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_dVfpNvHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_j1JcfVNs_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WMfXXAGu, m);
}

void Heavy_ChaffVerb::cBinop_xaYY6s38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Pw6XGGzx, m);
}

void Heavy_ChaffVerb::cMsg_OdsBSZoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dVfpNvHu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_j1JcfVNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bk38OOll, m);
}

void Heavy_ChaffVerb::cBinop_4hIEQdmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TG03f8pU, 0, m, &cVar_TG03f8pU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wAFoxYqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SLn0bx3C_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O5XwSybf_sendMessage);
}

void Heavy_ChaffVerb::cCast_O5XwSybf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4hIEQdmv, HV_BINOP_DIVIDE, 0, m, &cBinop_4hIEQdmv_sendMessage);
}

void Heavy_ChaffVerb::cCast_SLn0bx3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4hIEQdmv, HV_BINOP_DIVIDE, 1, m, &cBinop_4hIEQdmv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LpJbzcwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_D2urfxXH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_u0rHsiGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_eu4ZStMP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_D2urfxXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4hIEQdmv, HV_BINOP_DIVIDE, 0, m, &cBinop_4hIEQdmv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BNDGTwDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_rczTNGkv, 0, m, &cPack_rczTNGkv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pID1cwJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_wAFoxYqD_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_xhMlgPjs, 0, m, &cPack_xhMlgPjs_sendMessage);
}

void Heavy_ChaffVerb::cUnop_28xkgDT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nNOE8Rmb, 0, m, &cIf_nNOE8Rmb_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_N4Uzjg55_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ABRmPmHu_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1SDH2PjD_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EC8WvbqK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_ABRmPmHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nz40jdbn_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_1SDH2PjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ss6myNPw_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_EC8WvbqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vjotDcve_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_QZ5PJ9jh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Jxwpq87e_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Jxwpq87e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_15exIJUe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dD3lj4f1_sendMessage);
}

void Heavy_ChaffVerb::cVar_98ZFLQWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_UbUDRBNq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yH8vbQtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YWwY6kVY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YWwY6kVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mwXMlE8W, HV_BINOP_DIVIDE, 1, m, &cBinop_mwXMlE8W_sendMessage);
}

void Heavy_ChaffVerb::cBinop_15exIJUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NscNzoWr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NscNzoWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wgDBY61G, m);
}

void Heavy_ChaffVerb::cMsg_uguJMMvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OCB795Yq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OCB795Yq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QZ5PJ9jh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dD3lj4f1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_m2D7eUJt, m);
}

void Heavy_ChaffVerb::cBinop_UbUDRBNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_TI84Hvkb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TI84Hvkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mwXMlE8W, HV_BINOP_DIVIDE, 0, m, &cBinop_mwXMlE8W_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mwXMlE8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uguJMMvh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_36lXW6qD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_n4XJJv4F, 0, m, &cSlice_n4XJJv4F_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_2ADhlplZ, 0, m, &cRandom_2ADhlplZ_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_AVdAS6Li_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_QkcrSUye_sendMessage);
}

void Heavy_ChaffVerb::cUnop_QkcrSUye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_CjyGG9zE_sendMessage);
}

void Heavy_ChaffVerb::cRandom_2ADhlplZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_AVdAS6Li_sendMessage);
}

void Heavy_ChaffVerb::cSlice_n4XJJv4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_2ADhlplZ, 1, m, &cRandom_2ADhlplZ_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_AQ07Wzsg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_9jiewffE_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_9jiewffE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkIqGIVy_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_FnHuTXQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FnHuTXQB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FnHuTXQB, 0, m, &cDelay_FnHuTXQB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pDpSOC6L, 0, m, &cVar_pDpSOC6L_sendMessage);
}

void Heavy_ChaffVerb::cCast_nkIqGIVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9jiewffE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FnHuTXQB, 0, m, &cDelay_FnHuTXQB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pDpSOC6L, 0, m, &cVar_pDpSOC6L_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4vkdTRp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_va6GKY3F_sendMessage);
}

void Heavy_ChaffVerb::cSystem_va6GKY3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZUnKNsrd_sendMessage);
}

void Heavy_ChaffVerb::cVar_OKQMT6vc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bC3jAEt0, HV_BINOP_MULTIPLY, 0, m, &cBinop_bC3jAEt0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9jiewffE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FnHuTXQB, 0, m, &cDelay_FnHuTXQB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vnTyz5rR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FnHuTXQB, 2, m, &cDelay_FnHuTXQB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZUnKNsrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bC3jAEt0, HV_BINOP_MULTIPLY, 1, m, &cBinop_bC3jAEt0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bC3jAEt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_vnTyz5rR_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_VHNUpcyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_shCGl4OT, HV_BINOP_SUBTRACT, 0, m, &cBinop_shCGl4OT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DlVoXpom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cUbGDuO6_sendMessage);
}

void Heavy_ChaffVerb::cSystem_cUbGDuO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IdkGpIQw_sendMessage);
}

void Heavy_ChaffVerb::cVar_66UNRuIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JLpu3K77_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_sPL5hztK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sPL5hztK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8pDtPPPE, 0, m, &cDelay_8pDtPPPE_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_guWyVg9B, 0, m, &sTabread_guWyVg9B_sendMessage);
}

void Heavy_ChaffVerb::cDelay_8pDtPPPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8pDtPPPE, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_guWyVg9B, 0, m, &sTabread_guWyVg9B_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8pDtPPPE, 0, m, &cDelay_8pDtPPPE_sendMessage);
}

void Heavy_ChaffVerb::sTabread_guWyVg9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_sftBgHCS, HV_BINOP_SUBTRACT, 0, m, &cBinop_sftBgHCS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_f9QnJIfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sPnQPqt2, HV_BINOP_MAX, 0, m, &cBinop_sPnQPqt2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IdkGpIQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f9QnJIfe, HV_BINOP_MULTIPLY, 0, m, &cBinop_f9QnJIfe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_shCGl4OT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xsFMVrhX_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_guWyVg9B, 0, m, &sTabread_guWyVg9B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mHaP2xGH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Pr4182wD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sftBgHCS, HV_BINOP_SUBTRACT, 1, m, &cBinop_sftBgHCS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8pDtPPPE, 2, m, &cDelay_8pDtPPPE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JLpu3K77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Pr4182wD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xsFMVrhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sPL5hztK, 0, m, &cDelay_sPL5hztK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8pDtPPPE, 0, m, &cDelay_8pDtPPPE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rToy5fIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_sPnQPqt2, HV_BINOP_MAX, 1, m, &cBinop_sPnQPqt2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sPnQPqt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_shCGl4OT, HV_BINOP_SUBTRACT, 1, m, &cBinop_shCGl4OT_sendMessage);
}

void Heavy_ChaffVerb::cCast_mHaP2xGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sPL5hztK, 0, m, &cDelay_sPL5hztK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DintgxvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sPL5hztK, 2, m, &cDelay_sPL5hztK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sftBgHCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DintgxvO_sendMessage);
}

void Heavy_ChaffVerb::cCast_hFyH8J7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_66UNRuIJ, 0, m, &cVar_66UNRuIJ_sendMessage);
  cMsg_DlVoXpom_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_VHNUpcyY, 0, m, &cTabhead_VHNUpcyY_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_1MzJEVP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FzCsXLkb, HV_BINOP_SUBTRACT, 0, m, &cBinop_FzCsXLkb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uaWZChKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RyWYYhSP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_RyWYYhSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_sE6xYzih_sendMessage);
}

void Heavy_ChaffVerb::cVar_oSioy4RR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5l2WVsRk_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_CX7y5dPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CX7y5dPJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ej5Jp9Ha, 0, m, &cDelay_ej5Jp9Ha_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_n6s9zB6H, 0, m, &sTabread_n6s9zB6H_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ej5Jp9Ha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ej5Jp9Ha, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_n6s9zB6H, 0, m, &sTabread_n6s9zB6H_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ej5Jp9Ha, 0, m, &cDelay_ej5Jp9Ha_sendMessage);
}

void Heavy_ChaffVerb::sTabread_n6s9zB6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_mgEZeh48, HV_BINOP_SUBTRACT, 0, m, &cBinop_mgEZeh48_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_DUGJEKDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pAEQLpSs, HV_BINOP_MAX, 0, m, &cBinop_pAEQLpSs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sE6xYzih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DUGJEKDw, HV_BINOP_MULTIPLY, 0, m, &cBinop_DUGJEKDw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FzCsXLkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zTt3LsfO_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_n6s9zB6H, 0, m, &sTabread_n6s9zB6H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JdRE1FOU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_9kQhgZaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mgEZeh48, HV_BINOP_SUBTRACT, 1, m, &cBinop_mgEZeh48_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ej5Jp9Ha, 2, m, &cDelay_ej5Jp9Ha_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5l2WVsRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9kQhgZaW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zTt3LsfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CX7y5dPJ, 0, m, &cDelay_CX7y5dPJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ej5Jp9Ha, 0, m, &cDelay_ej5Jp9Ha_sendMessage);
}

void Heavy_ChaffVerb::cMsg_63dzpwrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_pAEQLpSs, HV_BINOP_MAX, 1, m, &cBinop_pAEQLpSs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pAEQLpSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FzCsXLkb, HV_BINOP_SUBTRACT, 1, m, &cBinop_FzCsXLkb_sendMessage);
}

void Heavy_ChaffVerb::cCast_JdRE1FOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CX7y5dPJ, 0, m, &cDelay_CX7y5dPJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_W0nw2I2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CX7y5dPJ, 2, m, &cDelay_CX7y5dPJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mgEZeh48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_W0nw2I2S_sendMessage);
}

void Heavy_ChaffVerb::cCast_0oM2Hs5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oSioy4RR, 0, m, &cVar_oSioy4RR_sendMessage);
  cMsg_uaWZChKu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1MzJEVP6, 0, m, &cTabhead_1MzJEVP6_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_MwQcb610_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TmSgqJ48, HV_BINOP_SUBTRACT, 0, m, &cBinop_TmSgqJ48_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rHZdSoS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xKhasjUW_sendMessage);
}

void Heavy_ChaffVerb::cSystem_xKhasjUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qGjCbO15_sendMessage);
}

void Heavy_ChaffVerb::cVar_flBywxs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_knHn7eqV_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_CKUtOVD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CKUtOVD9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dihycU3I, 0, m, &cDelay_dihycU3I_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_vEDhi6Rh, 0, m, &sTabread_vEDhi6Rh_sendMessage);
}

void Heavy_ChaffVerb::cDelay_dihycU3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dihycU3I, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_vEDhi6Rh, 0, m, &sTabread_vEDhi6Rh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dihycU3I, 0, m, &cDelay_dihycU3I_sendMessage);
}

void Heavy_ChaffVerb::sTabread_vEDhi6Rh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_b3LgSsB3, HV_BINOP_SUBTRACT, 0, m, &cBinop_b3LgSsB3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_lgT97wkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vh7oernu, HV_BINOP_MAX, 0, m, &cBinop_vh7oernu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qGjCbO15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lgT97wkE, HV_BINOP_MULTIPLY, 0, m, &cBinop_lgT97wkE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TmSgqJ48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ArDJd3A4_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_vEDhi6Rh, 0, m, &sTabread_vEDhi6Rh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bXuVUHbp_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wXPwgp4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b3LgSsB3, HV_BINOP_SUBTRACT, 1, m, &cBinop_b3LgSsB3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dihycU3I, 2, m, &cDelay_dihycU3I_sendMessage);
}

void Heavy_ChaffVerb::cMsg_knHn7eqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wXPwgp4i_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ArDJd3A4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CKUtOVD9, 0, m, &cDelay_CKUtOVD9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dihycU3I, 0, m, &cDelay_dihycU3I_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HJf3cDOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_vh7oernu, HV_BINOP_MAX, 1, m, &cBinop_vh7oernu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vh7oernu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TmSgqJ48, HV_BINOP_SUBTRACT, 1, m, &cBinop_TmSgqJ48_sendMessage);
}

void Heavy_ChaffVerb::cCast_bXuVUHbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CKUtOVD9, 0, m, &cDelay_CKUtOVD9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dmIYJv3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CKUtOVD9, 2, m, &cDelay_CKUtOVD9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_b3LgSsB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dmIYJv3E_sendMessage);
}

void Heavy_ChaffVerb::cCast_wyWGZpZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_flBywxs2, 0, m, &cVar_flBywxs2_sendMessage);
  cMsg_rHZdSoS3_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MwQcb610, 0, m, &cTabhead_MwQcb610_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_bkqdNuFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TmG7fbpi, HV_BINOP_SUBTRACT, 0, m, &cBinop_TmG7fbpi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CdiH7B7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YreIcpqT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YreIcpqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_iwRQsw11_sendMessage);
}

void Heavy_ChaffVerb::cVar_TvCobsRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TICcZhuL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_pQ8WzMxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pQ8WzMxh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1LAhkyZE, 0, m, &cDelay_1LAhkyZE_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_N6lRVyoH, 0, m, &sTabread_N6lRVyoH_sendMessage);
}

void Heavy_ChaffVerb::cDelay_1LAhkyZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1LAhkyZE, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_N6lRVyoH, 0, m, &sTabread_N6lRVyoH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1LAhkyZE, 0, m, &cDelay_1LAhkyZE_sendMessage);
}

void Heavy_ChaffVerb::sTabread_N6lRVyoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_teLBG4mf, HV_BINOP_SUBTRACT, 0, m, &cBinop_teLBG4mf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_LmsHbmNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BY2nC7Kk, HV_BINOP_MAX, 0, m, &cBinop_BY2nC7Kk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iwRQsw11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LmsHbmNs, HV_BINOP_MULTIPLY, 0, m, &cBinop_LmsHbmNs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TmG7fbpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xFdrIm2W_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_N6lRVyoH, 0, m, &sTabread_N6lRVyoH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RrvsRUdA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_bUDW4VFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_teLBG4mf, HV_BINOP_SUBTRACT, 1, m, &cBinop_teLBG4mf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1LAhkyZE, 2, m, &cDelay_1LAhkyZE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TICcZhuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bUDW4VFj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xFdrIm2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pQ8WzMxh, 0, m, &cDelay_pQ8WzMxh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1LAhkyZE, 0, m, &cDelay_1LAhkyZE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Vbx8dKzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_BY2nC7Kk, HV_BINOP_MAX, 1, m, &cBinop_BY2nC7Kk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BY2nC7Kk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TmG7fbpi, HV_BINOP_SUBTRACT, 1, m, &cBinop_TmG7fbpi_sendMessage);
}

void Heavy_ChaffVerb::cCast_RrvsRUdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pQ8WzMxh, 0, m, &cDelay_pQ8WzMxh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_orLmVQbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pQ8WzMxh, 2, m, &cDelay_pQ8WzMxh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_teLBG4mf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_orLmVQbM_sendMessage);
}

void Heavy_ChaffVerb::cCast_9TvO6XQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TvCobsRN, 0, m, &cVar_TvCobsRN_sendMessage);
  cMsg_CdiH7B7V_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_bkqdNuFv, 0, m, &cTabhead_bkqdNuFv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9yfStTvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_g5zxFviS_sendMessage);
}

void Heavy_ChaffVerb::cSystem_g5zxFviS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XELuAYzp_sendMessage);
}

void Heavy_ChaffVerb::cDelay_FbZoSyK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FbZoSyK0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sgYsgubx, 0, m, &cDelay_sgYsgubx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FbZoSyK0, 0, m, &cDelay_FbZoSyK0_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5ueQZyas, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_sgYsgubx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sgYsgubx, m);
  cMsg_jCU7BPdj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_dv19qyGT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_EbgtpfQx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_cNkCOWWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hns1kfkR_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_YYgapYIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2xNzIaGD_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FbZoSyK0, 2, m, &cDelay_FbZoSyK0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WG2BLU9G_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Hns1kfkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_YYgapYIQ, 0, m, &hTable_YYgapYIQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XELuAYzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_cNkCOWWp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jCU7BPdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_YYgapYIQ, 0, m, &hTable_YYgapYIQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_WG2BLU9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FbZoSyK0, 0, m, &cDelay_FbZoSyK0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2xNzIaGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_sgYsgubx, 2, m, &cDelay_sgYsgubx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EbgtpfQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5ueQZyas, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_3QFyFfvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AYs6t4is_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AYs6t4is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Jdf8Nhnk_sendMessage);
}

void Heavy_ChaffVerb::cDelay_YcoQSbzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YcoQSbzb, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yTrjeKmD, 0, m, &cDelay_yTrjeKmD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YcoQSbzb, 0, m, &cDelay_YcoQSbzb_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ZDs6rfmz, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_yTrjeKmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yTrjeKmD, m);
  cMsg_2Z8BfDP7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_T7sgCj88_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_9Q1EAMK6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_yxfcctM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3mdZGj2S_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_OyoFPstG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AiatWb87_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YcoQSbzb, 2, m, &cDelay_YcoQSbzb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2tSh0i4D_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3mdZGj2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_OyoFPstG, 0, m, &hTable_OyoFPstG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Jdf8Nhnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_yxfcctM4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2Z8BfDP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_OyoFPstG, 0, m, &hTable_OyoFPstG_sendMessage);
}

void Heavy_ChaffVerb::cCast_2tSh0i4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YcoQSbzb, 0, m, &cDelay_YcoQSbzb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AiatWb87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_yTrjeKmD, 2, m, &cDelay_yTrjeKmD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9Q1EAMK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ZDs6rfmz, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_HQ7onNKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_koYyMGx3_sendMessage);
}

void Heavy_ChaffVerb::cSystem_koYyMGx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_i0gbdMDJ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_cq5wqCU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cq5wqCU9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qemwhIIy, 0, m, &cDelay_qemwhIIy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cq5wqCU9, 0, m, &cDelay_cq5wqCU9_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1PE4jJf8, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_qemwhIIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qemwhIIy, m);
  cMsg_IsutIGwD_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_lCrwzMWn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_WEuA9TRs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_DXWoaflb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MIhUc3aD_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_1lDxc7X2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sdbTqmsr_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cq5wqCU9, 2, m, &cDelay_cq5wqCU9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zbjfAelc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MIhUc3aD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_1lDxc7X2, 0, m, &hTable_1lDxc7X2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_i0gbdMDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_DXWoaflb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IsutIGwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_1lDxc7X2, 0, m, &hTable_1lDxc7X2_sendMessage);
}

void Heavy_ChaffVerb::cCast_zbjfAelc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cq5wqCU9, 0, m, &cDelay_cq5wqCU9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sdbTqmsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_qemwhIIy, 2, m, &cDelay_qemwhIIy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WEuA9TRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1PE4jJf8, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_YvY1vgPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VnfVDer7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VnfVDer7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8xdUANms_sendMessage);
}

void Heavy_ChaffVerb::cDelay_oRH1FC0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oRH1FC0X, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DoBZbNQl, 0, m, &cDelay_DoBZbNQl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oRH1FC0X, 0, m, &cDelay_oRH1FC0X_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_aUIH03YJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_DoBZbNQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DoBZbNQl, m);
  cMsg_msBW83no_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_bTRhzfZ1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_AA3DtuSV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_4Jfca7di_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m8jwjukJ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_JsdBq0hM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KDzULgCA_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oRH1FC0X, 2, m, &cDelay_oRH1FC0X_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dz0qmaAJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_m8jwjukJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_JsdBq0hM, 0, m, &hTable_JsdBq0hM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8xdUANms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_4Jfca7di_sendMessage);
}

void Heavy_ChaffVerb::cMsg_msBW83no_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_JsdBq0hM, 0, m, &hTable_JsdBq0hM_sendMessage);
}

void Heavy_ChaffVerb::cCast_Dz0qmaAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oRH1FC0X, 0, m, &cDelay_oRH1FC0X_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KDzULgCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_DoBZbNQl, 2, m, &cDelay_DoBZbNQl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AA3DtuSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_aUIH03YJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_yDdv8NDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_OuJ1r92g, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_3MqyQ3Ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_3U3TA50p, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_A8lfzEXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LXV0i320_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LXV0i320_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_Yc88O5w0_sendMessage);
}

void Heavy_ChaffVerb::cVar_DzGgnI8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mVzzejFR, HV_BINOP_MULTIPLY, 0, m, &cBinop_mVzzejFR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3eb1Xok9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_n1UBytL7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_n1UBytL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JQaLa3sG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_mVzzejFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uRLoHHnD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nnfOYEvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mVzzejFR, HV_BINOP_MULTIPLY, 1, m, &cBinop_mVzzejFR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JQaLa3sG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nnfOYEvA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uRLoHHnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fVELWqzq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fVELWqzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GJOWPYkT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MgMfgY4V, m);
}

void Heavy_ChaffVerb::cBinop_GJOWPYkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Sj6KzPbl, m);
}

void Heavy_ChaffVerb::cVar_YtI9UFlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_n1h4YNeR_sendMessage);
}

void Heavy_ChaffVerb::cVar_FHFZmOYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_A8lfzEXW_sendMessage);
}

void Heavy_ChaffVerb::cVar_EXzgjIwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_bR5fB3SI_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_zOb6ycjj, 0, m, &cIf_zOb6ycjj_sendMessage);
}

void Heavy_ChaffVerb::cVar_S1t03x3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_iNpQYc74_sendMessage);
}

void Heavy_ChaffVerb::cIf_zOb6ycjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_y6jrIbwo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_3EdXkCod, 0, m, &cVar_3EdXkCod_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_bR5fB3SI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zOb6ycjj, 1, m, &cIf_zOb6ycjj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iNpQYc74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FER5zByB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FER5zByB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xpNlYWgg, 0, m, &cVar_xpNlYWgg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rWVrliwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VZhkc25t_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VZhkc25t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_C6W7aj2z_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Cz2f2Z1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Cz2f2Z1Q, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ovBvcaqE, 0, m, &cDelay_ovBvcaqE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cz2f2Z1Q, 0, m, &cDelay_Cz2f2Z1Q_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_zd4xJu88, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_ovBvcaqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ovBvcaqE, m);
  cMsg_A02Ghgda_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_3Wr7aieP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_XS2SGQaS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_WTfIpkWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n7CuCdjr_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_cN7vkwfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GCjUKZz3_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cz2f2Z1Q, 2, m, &cDelay_Cz2f2Z1Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xBLhfyaN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_n7CuCdjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_cN7vkwfD, 0, m, &hTable_cN7vkwfD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_C6W7aj2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_WTfIpkWE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A02Ghgda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_cN7vkwfD, 0, m, &hTable_cN7vkwfD_sendMessage);
}

void Heavy_ChaffVerb::cCast_xBLhfyaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cz2f2Z1Q, 0, m, &cDelay_Cz2f2Z1Q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GCjUKZz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ovBvcaqE, 2, m, &cDelay_ovBvcaqE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XS2SGQaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_zd4xJu88, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_S6dA0o4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uVYDjQQo, HV_BINOP_SUBTRACT, 0, m, &cBinop_uVYDjQQo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Y46bO6Bw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8Ng7A0Ry_sendMessage);
}

void Heavy_ChaffVerb::cSystem_8Ng7A0Ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_V1B90lIh_sendMessage);
}

void Heavy_ChaffVerb::cVar_alUUrjTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DUGG4hzn_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_hw9qNDt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hw9qNDt2, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hbXRLznR, 0, m, &cDelay_hbXRLznR_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MkzWsSW2, 0, m, &sTabread_MkzWsSW2_sendMessage);
}

void Heavy_ChaffVerb::cDelay_hbXRLznR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hbXRLznR, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MkzWsSW2, 0, m, &sTabread_MkzWsSW2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hbXRLznR, 0, m, &cDelay_hbXRLznR_sendMessage);
}

void Heavy_ChaffVerb::sTabread_MkzWsSW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_siMuCCFN, HV_BINOP_SUBTRACT, 0, m, &cBinop_siMuCCFN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_TGcvO5D4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n60CbpQj, HV_BINOP_MAX, 0, m, &cBinop_n60CbpQj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_V1B90lIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TGcvO5D4, HV_BINOP_MULTIPLY, 0, m, &cBinop_TGcvO5D4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uVYDjQQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8TvMsSwu_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MkzWsSW2, 0, m, &sTabread_MkzWsSW2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tvj0vOS7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_KGTUAslg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_siMuCCFN, HV_BINOP_SUBTRACT, 1, m, &cBinop_siMuCCFN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hbXRLznR, 2, m, &cDelay_hbXRLznR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DUGG4hzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KGTUAslg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8TvMsSwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hw9qNDt2, 0, m, &cDelay_hw9qNDt2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hbXRLznR, 0, m, &cDelay_hbXRLznR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZAcd3uka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_n60CbpQj, HV_BINOP_MAX, 1, m, &cBinop_n60CbpQj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_n60CbpQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uVYDjQQo, HV_BINOP_SUBTRACT, 1, m, &cBinop_uVYDjQQo_sendMessage);
}

void Heavy_ChaffVerb::cCast_tvj0vOS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hw9qNDt2, 0, m, &cDelay_hw9qNDt2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Nozwbkph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hw9qNDt2, 2, m, &cDelay_hw9qNDt2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_siMuCCFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Nozwbkph_sendMessage);
}

void Heavy_ChaffVerb::cCast_tWEHAW3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_alUUrjTT, 0, m, &cVar_alUUrjTT_sendMessage);
  cMsg_Y46bO6Bw_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_S6dA0o4k, 0, m, &cTabhead_S6dA0o4k_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5MrJJmeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uqOJ0u80_sendMessage);
}

void Heavy_ChaffVerb::cSystem_uqOJ0u80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_l2RwkR3x_sendMessage);
}

void Heavy_ChaffVerb::cDelay_FRQYETV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FRQYETV9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hBxjXakN, 0, m, &cDelay_hBxjXakN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FRQYETV9, 0, m, &cDelay_FRQYETV9_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_X0zvk12g, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_hBxjXakN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hBxjXakN, m);
  cMsg_aeTbjeuh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_GrOXOOcA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_epA0DF7n_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_GiYPFshh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6yHbllvw_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_5dkr0VM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y12eZNb7_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FRQYETV9, 2, m, &cDelay_FRQYETV9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xlGPrLqN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6yHbllvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_5dkr0VM0, 0, m, &hTable_5dkr0VM0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_l2RwkR3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_GiYPFshh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aeTbjeuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_5dkr0VM0, 0, m, &hTable_5dkr0VM0_sendMessage);
}

void Heavy_ChaffVerb::cCast_xlGPrLqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FRQYETV9, 0, m, &cDelay_FRQYETV9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_y12eZNb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hBxjXakN, 2, m, &cDelay_hBxjXakN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_epA0DF7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_X0zvk12g, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_5hqF6Qbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HeNzxhEk, HV_BINOP_SUBTRACT, 0, m, &cBinop_HeNzxhEk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_H2I5CIsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VQ2Wmu1p_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VQ2Wmu1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cjR3d3Gr_sendMessage);
}

void Heavy_ChaffVerb::cVar_pPIFiRJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2WFKdkNJ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_eC8WAeg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eC8WAeg9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AxMKF2k9, 0, m, &cDelay_AxMKF2k9_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_vMdXOTR5, 0, m, &sTabread_vMdXOTR5_sendMessage);
}

void Heavy_ChaffVerb::cDelay_AxMKF2k9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AxMKF2k9, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_vMdXOTR5, 0, m, &sTabread_vMdXOTR5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AxMKF2k9, 0, m, &cDelay_AxMKF2k9_sendMessage);
}

void Heavy_ChaffVerb::sTabread_vMdXOTR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_XNuBai5V, HV_BINOP_SUBTRACT, 0, m, &cBinop_XNuBai5V_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_kgHL7wcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zVe9SaeI, HV_BINOP_MAX, 0, m, &cBinop_zVe9SaeI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cjR3d3Gr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kgHL7wcW, HV_BINOP_MULTIPLY, 0, m, &cBinop_kgHL7wcW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HeNzxhEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YVLH3SJL_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_vMdXOTR5, 0, m, &sTabread_vMdXOTR5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tnZ3R0pw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FnlbCqst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XNuBai5V, HV_BINOP_SUBTRACT, 1, m, &cBinop_XNuBai5V_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AxMKF2k9, 2, m, &cDelay_AxMKF2k9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2WFKdkNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FnlbCqst_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YVLH3SJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eC8WAeg9, 0, m, &cDelay_eC8WAeg9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AxMKF2k9, 0, m, &cDelay_AxMKF2k9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FwWBWsdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_zVe9SaeI, HV_BINOP_MAX, 1, m, &cBinop_zVe9SaeI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zVe9SaeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HeNzxhEk, HV_BINOP_SUBTRACT, 1, m, &cBinop_HeNzxhEk_sendMessage);
}

void Heavy_ChaffVerb::cCast_tnZ3R0pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eC8WAeg9, 0, m, &cDelay_eC8WAeg9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rHqEB7fm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eC8WAeg9, 2, m, &cDelay_eC8WAeg9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XNuBai5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rHqEB7fm_sendMessage);
}

void Heavy_ChaffVerb::cCast_GbgUEbTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pPIFiRJX, 0, m, &cVar_pPIFiRJX_sendMessage);
  cMsg_H2I5CIsT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5hqF6Qbl, 0, m, &cTabhead_5hqF6Qbl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IFldoeC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PxcgYYxQ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_PxcgYYxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XaGRjxob_sendMessage);
}

void Heavy_ChaffVerb::cDelay_5qa3Njj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5qa3Njj4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WDHof3pu, 0, m, &cDelay_WDHof3pu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5qa3Njj4, 0, m, &cDelay_5qa3Njj4_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_O41y9N0s, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_WDHof3pu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WDHof3pu, m);
  cMsg_ntbHOA0A_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_ZN26ASN0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_qR2CTonJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_nfb93Hel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xf2zUvRc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_llIHknGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1IWrhhy0_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5qa3Njj4, 2, m, &cDelay_5qa3Njj4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wejsxl8f_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xf2zUvRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_llIHknGv, 0, m, &hTable_llIHknGv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XaGRjxob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_nfb93Hel_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ntbHOA0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_llIHknGv, 0, m, &hTable_llIHknGv_sendMessage);
}

void Heavy_ChaffVerb::cCast_Wejsxl8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5qa3Njj4, 0, m, &cDelay_5qa3Njj4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1IWrhhy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_WDHof3pu, 2, m, &cDelay_WDHof3pu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qR2CTonJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_O41y9N0s, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_iEuHz5ip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TooEMthp, HV_BINOP_SUBTRACT, 0, m, &cBinop_TooEMthp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_O2YNCM3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7wckEI9B_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7wckEI9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_eCBGoulC_sendMessage);
}

void Heavy_ChaffVerb::cVar_Wmo9EFSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_95rqRrDe_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_SFmBhoe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SFmBhoe8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bw45hEJT, 0, m, &cDelay_bw45hEJT_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_HDOMTeYp, 0, m, &sTabread_HDOMTeYp_sendMessage);
}

void Heavy_ChaffVerb::cDelay_bw45hEJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bw45hEJT, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_HDOMTeYp, 0, m, &sTabread_HDOMTeYp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bw45hEJT, 0, m, &cDelay_bw45hEJT_sendMessage);
}

void Heavy_ChaffVerb::sTabread_HDOMTeYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_CmcUV5Ba, HV_BINOP_SUBTRACT, 0, m, &cBinop_CmcUV5Ba_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_RpMeb8f2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sUILQQrm, HV_BINOP_MAX, 0, m, &cBinop_sUILQQrm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eCBGoulC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RpMeb8f2, HV_BINOP_MULTIPLY, 0, m, &cBinop_RpMeb8f2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TooEMthp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xi5ZGIIS_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_HDOMTeYp, 0, m, &sTabread_HDOMTeYp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1pOWDi9A_sendMessage);
}

void Heavy_ChaffVerb::cSystem_uHuvNHLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CmcUV5Ba, HV_BINOP_SUBTRACT, 1, m, &cBinop_CmcUV5Ba_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bw45hEJT, 2, m, &cDelay_bw45hEJT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_95rqRrDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uHuvNHLc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xi5ZGIIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SFmBhoe8, 0, m, &cDelay_SFmBhoe8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bw45hEJT, 0, m, &cDelay_bw45hEJT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4hHgeszQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_sUILQQrm, HV_BINOP_MAX, 1, m, &cBinop_sUILQQrm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sUILQQrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TooEMthp, HV_BINOP_SUBTRACT, 1, m, &cBinop_TooEMthp_sendMessage);
}

void Heavy_ChaffVerb::cCast_1pOWDi9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SFmBhoe8, 0, m, &cDelay_SFmBhoe8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nJRzR57U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SFmBhoe8, 2, m, &cDelay_SFmBhoe8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CmcUV5Ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nJRzR57U_sendMessage);
}

void Heavy_ChaffVerb::cCast_PAxkgKYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wmo9EFSb, 0, m, &cVar_Wmo9EFSb_sendMessage);
  cMsg_O2YNCM3h_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_iEuHz5ip, 0, m, &cTabhead_iEuHz5ip_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KdxdNUDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tdA34QYx_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tdA34QYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3zL2FqSV_sendMessage);
}

void Heavy_ChaffVerb::cDelay_iaIwWhuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iaIwWhuN, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kfhmWrOB, 0, m, &cDelay_kfhmWrOB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iaIwWhuN, 0, m, &cDelay_iaIwWhuN_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Y0Yi1BAy, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_kfhmWrOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kfhmWrOB, m);
  cMsg_G0qGILSO_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_KSx2Z53i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Tkw1o5Ac_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_pL8NeoC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dBSiWaW5_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_F516Uqpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LBvZdBcj_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iaIwWhuN, 2, m, &cDelay_iaIwWhuN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tGzSA8Uo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dBSiWaW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_F516Uqpi, 0, m, &hTable_F516Uqpi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3zL2FqSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_pL8NeoC5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_G0qGILSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_F516Uqpi, 0, m, &hTable_F516Uqpi_sendMessage);
}

void Heavy_ChaffVerb::cCast_tGzSA8Uo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iaIwWhuN, 0, m, &cDelay_iaIwWhuN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LBvZdBcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_kfhmWrOB, 2, m, &cDelay_kfhmWrOB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Tkw1o5Ac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Y0Yi1BAy, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_fj1lZdUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3kyb56wS, HV_BINOP_SUBTRACT, 0, m, &cBinop_3kyb56wS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wTuiB7iN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eYmixoRt_sendMessage);
}

void Heavy_ChaffVerb::cSystem_eYmixoRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_eX0htzkI_sendMessage);
}

void Heavy_ChaffVerb::cVar_mW0vqLUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y0JHKpRz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_um22hswr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_um22hswr, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2G8DLU2f, 0, m, &cDelay_2G8DLU2f_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_RnN0W5Qf, 0, m, &sTabread_RnN0W5Qf_sendMessage);
}

void Heavy_ChaffVerb::cDelay_2G8DLU2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2G8DLU2f, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_RnN0W5Qf, 0, m, &sTabread_RnN0W5Qf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2G8DLU2f, 0, m, &cDelay_2G8DLU2f_sendMessage);
}

void Heavy_ChaffVerb::sTabread_RnN0W5Qf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yIM65ckL, HV_BINOP_SUBTRACT, 0, m, &cBinop_yIM65ckL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_LCxgjSiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wwo3mej1, HV_BINOP_MAX, 0, m, &cBinop_wwo3mej1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eX0htzkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LCxgjSiM, HV_BINOP_MULTIPLY, 0, m, &cBinop_LCxgjSiM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3kyb56wS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xrsByR34_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_RnN0W5Qf, 0, m, &sTabread_RnN0W5Qf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zxkbwfeo_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ScWGY4iQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yIM65ckL, HV_BINOP_SUBTRACT, 1, m, &cBinop_yIM65ckL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2G8DLU2f, 2, m, &cDelay_2G8DLU2f_sendMessage);
}

void Heavy_ChaffVerb::cMsg_y0JHKpRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ScWGY4iQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xrsByR34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_um22hswr, 0, m, &cDelay_um22hswr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2G8DLU2f, 0, m, &cDelay_2G8DLU2f_sendMessage);
}

void Heavy_ChaffVerb::cMsg_n2oAmHN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_wwo3mej1, HV_BINOP_MAX, 1, m, &cBinop_wwo3mej1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wwo3mej1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3kyb56wS, HV_BINOP_SUBTRACT, 1, m, &cBinop_3kyb56wS_sendMessage);
}

void Heavy_ChaffVerb::cCast_zxkbwfeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_um22hswr, 0, m, &cDelay_um22hswr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Rk8MZVhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_um22hswr, 2, m, &cDelay_um22hswr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yIM65ckL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Rk8MZVhx_sendMessage);
}

void Heavy_ChaffVerb::cCast_PXP0csZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mW0vqLUQ, 0, m, &cVar_mW0vqLUQ_sendMessage);
  cMsg_wTuiB7iN_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_fj1lZdUQ, 0, m, &cTabhead_fj1lZdUQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jeOrtWOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pCGR3vUf_sendMessage);
}

void Heavy_ChaffVerb::cSystem_pCGR3vUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GVGRggWx_sendMessage);
}

void Heavy_ChaffVerb::cDelay_OWBEiKrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OWBEiKrM, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_D5TgJW3e, 0, m, &cDelay_D5TgJW3e_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OWBEiKrM, 0, m, &cDelay_OWBEiKrM_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_92FFn8B7, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_D5TgJW3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D5TgJW3e, m);
  cMsg_jaTpergB_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Xni2Z8wQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_CaPKjuCe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_iDz6a8Q2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9QY42O67_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_dKlOBRo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dpDQ3R0d_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OWBEiKrM, 2, m, &cDelay_OWBEiKrM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2YaY8Yl8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9QY42O67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_dKlOBRo3, 0, m, &hTable_dKlOBRo3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GVGRggWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_iDz6a8Q2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jaTpergB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_dKlOBRo3, 0, m, &hTable_dKlOBRo3_sendMessage);
}

void Heavy_ChaffVerb::cCast_2YaY8Yl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OWBEiKrM, 0, m, &cDelay_OWBEiKrM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dpDQ3R0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_D5TgJW3e, 2, m, &cDelay_D5TgJW3e_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CaPKjuCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_92FFn8B7, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_Gwqtjw7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WipDfrZC, HV_BINOP_SUBTRACT, 0, m, &cBinop_WipDfrZC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9kcrLNps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aamGGB9h_sendMessage);
}

void Heavy_ChaffVerb::cSystem_aamGGB9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qO0DTGKM_sendMessage);
}

void Heavy_ChaffVerb::cVar_3CK57A1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ozCQRa2z_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_7Ik0lZjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7Ik0lZjo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_spqoLhtO, 0, m, &cDelay_spqoLhtO_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_haIi5phZ, 0, m, &sTabread_haIi5phZ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_spqoLhtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_spqoLhtO, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_haIi5phZ, 0, m, &sTabread_haIi5phZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_spqoLhtO, 0, m, &cDelay_spqoLhtO_sendMessage);
}

void Heavy_ChaffVerb::sTabread_haIi5phZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_0OHVNLqd, HV_BINOP_SUBTRACT, 0, m, &cBinop_0OHVNLqd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_mrTyzjM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4udw43pg, HV_BINOP_MAX, 0, m, &cBinop_4udw43pg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qO0DTGKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mrTyzjM9, HV_BINOP_MULTIPLY, 0, m, &cBinop_mrTyzjM9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WipDfrZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N8aJYI2R_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_haIi5phZ, 0, m, &sTabread_haIi5phZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FQn3FFze_sendMessage);
}

void Heavy_ChaffVerb::cSystem_d1woP1HS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0OHVNLqd, HV_BINOP_SUBTRACT, 1, m, &cBinop_0OHVNLqd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_spqoLhtO, 2, m, &cDelay_spqoLhtO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ozCQRa2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_d1woP1HS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_N8aJYI2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7Ik0lZjo, 0, m, &cDelay_7Ik0lZjo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_spqoLhtO, 0, m, &cDelay_spqoLhtO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8EW6vDAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_4udw43pg, HV_BINOP_MAX, 1, m, &cBinop_4udw43pg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4udw43pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WipDfrZC, HV_BINOP_SUBTRACT, 1, m, &cBinop_WipDfrZC_sendMessage);
}

void Heavy_ChaffVerb::cCast_FQn3FFze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7Ik0lZjo, 0, m, &cDelay_7Ik0lZjo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lFRA32OX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7Ik0lZjo, 2, m, &cDelay_7Ik0lZjo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0OHVNLqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lFRA32OX_sendMessage);
}

void Heavy_ChaffVerb::cCast_kORUFpVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3CK57A1A, 0, m, &cVar_3CK57A1A_sendMessage);
  cMsg_9kcrLNps_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Gwqtjw7X, 0, m, &cTabhead_Gwqtjw7X_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gAvmoMPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_L5ef4xyj_sendMessage);
}

void Heavy_ChaffVerb::cSystem_L5ef4xyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2iGBceQy_sendMessage);
}

void Heavy_ChaffVerb::cDelay_QG9xtvyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QG9xtvyA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cpEOJFKX, 0, m, &cDelay_cpEOJFKX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QG9xtvyA, 0, m, &cDelay_QG9xtvyA_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oAtZ59Fu, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_cpEOJFKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cpEOJFKX, m);
  cMsg_CLJxjN5c_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_knMn0Eak_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_saUiLEl7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_AV6qeuQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ArFaJQcC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_yguk0PG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hiWTsA0x_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QG9xtvyA, 2, m, &cDelay_QG9xtvyA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rWoQHS72_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ArFaJQcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_yguk0PG0, 0, m, &hTable_yguk0PG0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2iGBceQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_AV6qeuQS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CLJxjN5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_yguk0PG0, 0, m, &hTable_yguk0PG0_sendMessage);
}

void Heavy_ChaffVerb::cCast_rWoQHS72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QG9xtvyA, 0, m, &cDelay_QG9xtvyA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hiWTsA0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_cpEOJFKX, 2, m, &cDelay_cpEOJFKX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_saUiLEl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oAtZ59Fu, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_jwI9Xa6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_955OAG0c, HV_BINOP_SUBTRACT, 0, m, &cBinop_955OAG0c_sendMessage);
}

void Heavy_ChaffVerb::cMsg_l2HJnGSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_guPjZrYq_sendMessage);
}

void Heavy_ChaffVerb::cSystem_guPjZrYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_YxiRY8hy_sendMessage);
}

void Heavy_ChaffVerb::cVar_4xZCBs1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MMoFUP2c_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_4KzR9MHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4KzR9MHg, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_slVdgPrc, 0, m, &cDelay_slVdgPrc_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VOnK3mhv, 0, m, &sTabread_VOnK3mhv_sendMessage);
}

void Heavy_ChaffVerb::cDelay_slVdgPrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_slVdgPrc, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VOnK3mhv, 0, m, &sTabread_VOnK3mhv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_slVdgPrc, 0, m, &cDelay_slVdgPrc_sendMessage);
}

void Heavy_ChaffVerb::sTabread_VOnK3mhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_gs5qscca, HV_BINOP_SUBTRACT, 0, m, &cBinop_gs5qscca_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_ta3ws88l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V2xJwhBO, HV_BINOP_MAX, 0, m, &cBinop_V2xJwhBO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YxiRY8hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ta3ws88l, HV_BINOP_MULTIPLY, 0, m, &cBinop_ta3ws88l_sendMessage);
}

void Heavy_ChaffVerb::cBinop_955OAG0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e29w4Kk8_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VOnK3mhv, 0, m, &sTabread_VOnK3mhv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wU52poua_sendMessage);
}

void Heavy_ChaffVerb::cSystem_1mNoe7Fs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gs5qscca, HV_BINOP_SUBTRACT, 1, m, &cBinop_gs5qscca_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_slVdgPrc, 2, m, &cDelay_slVdgPrc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MMoFUP2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1mNoe7Fs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_e29w4Kk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4KzR9MHg, 0, m, &cDelay_4KzR9MHg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_slVdgPrc, 0, m, &cDelay_slVdgPrc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JtQ9aevW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_V2xJwhBO, HV_BINOP_MAX, 1, m, &cBinop_V2xJwhBO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_V2xJwhBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_955OAG0c, HV_BINOP_SUBTRACT, 1, m, &cBinop_955OAG0c_sendMessage);
}

void Heavy_ChaffVerb::cCast_wU52poua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4KzR9MHg, 0, m, &cDelay_4KzR9MHg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KvkvSUha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4KzR9MHg, 2, m, &cDelay_4KzR9MHg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gs5qscca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KvkvSUha_sendMessage);
}

void Heavy_ChaffVerb::cCast_QkpMrLeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4xZCBs1H, 0, m, &cVar_4xZCBs1H_sendMessage);
  cMsg_l2HJnGSz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_jwI9Xa6u, 0, m, &cTabhead_jwI9Xa6u_sendMessage);
}

void Heavy_ChaffVerb::cVar_3EdXkCod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DzGgnI8S, 0, m, &cVar_DzGgnI8S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vjuWVpod, 0, m, &cVar_vjuWVpod_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GAEOgI0W, 0, m, &cVar_GAEOgI0W_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cSbz2AVe, 0, m, &cVar_cSbz2AVe_sendMessage);
}

void Heavy_ChaffVerb::cVar_xpNlYWgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_BznefzsL_sendMessage);
}

void Heavy_ChaffVerb::cPack_dPLg30SA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_gcmhCJGh, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_vjuWVpod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iVs1nQBi, HV_BINOP_MULTIPLY, 0, m, &cBinop_iVs1nQBi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DBlnray8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ImRkrhaq_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ImRkrhaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zSUVpb3c_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_iVs1nQBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_80W1IioP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SxjxPBKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iVs1nQBi, HV_BINOP_MULTIPLY, 1, m, &cBinop_iVs1nQBi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zSUVpb3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SxjxPBKJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_80W1IioP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_cJJpw5ct_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cJJpw5ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pngzgPis_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zosRLRdY, m);
}

void Heavy_ChaffVerb::cBinop_pngzgPis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9Ase1ZHW, m);
}

void Heavy_ChaffVerb::cVar_GAEOgI0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WFIiVKuT, HV_BINOP_MULTIPLY, 0, m, &cBinop_WFIiVKuT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ysskyK13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_adWo5amP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_adWo5amP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6nNjNe4U_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_WFIiVKuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_nzogPsdD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TEOnhomE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WFIiVKuT, HV_BINOP_MULTIPLY, 1, m, &cBinop_WFIiVKuT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6nNjNe4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TEOnhomE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nzogPsdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rCUPVDmI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rCUPVDmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Evvs4LfW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_o59suLKx, m);
}

void Heavy_ChaffVerb::cBinop_Evvs4LfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ThuXaZPy, m);
}

void Heavy_ChaffVerb::cVar_cSbz2AVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F1xYnzDG, HV_BINOP_MULTIPLY, 0, m, &cBinop_F1xYnzDG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MR4HIrKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jaGBWKSN_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jaGBWKSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H712xHEz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_F1xYnzDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_WgAHkgKl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DcVDzXxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F1xYnzDG, HV_BINOP_MULTIPLY, 1, m, &cBinop_F1xYnzDG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_H712xHEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DcVDzXxH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WgAHkgKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FzKbJjTY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FzKbJjTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xRzfKbT1_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CwFhWOxb, m);
}

void Heavy_ChaffVerb::cBinop_xRzfKbT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XwL3bbJ5, m);
}

void Heavy_ChaffVerb::cBinop_Yc88O5w0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_3MqyQ3Ic, 0, m, &cPack_3MqyQ3Ic_sendMessage);
}

void Heavy_ChaffVerb::cMsg_y6jrIbwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_3EdXkCod, 0, m, &cVar_3EdXkCod_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BznefzsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_dPLg30SA, 0, m, &cPack_dPLg30SA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_n1h4YNeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_yDdv8NDm, 0, m, &cPack_yDdv8NDm_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_j4mUZ5kX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_xKOm0zWQ_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_xKOm0zWQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_obb3bAXM_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_MAXP30XF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MAXP30XF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MAXP30XF, 0, m, &cDelay_MAXP30XF_sendMessage);
  cSwitchcase_36lXW6qD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_obb3bAXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xKOm0zWQ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MAXP30XF, 0, m, &cDelay_MAXP30XF_sendMessage);
  cSwitchcase_36lXW6qD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_Q6lLSRJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rX81MUVy_sendMessage);
}

void Heavy_ChaffVerb::cSystem_rX81MUVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_STC9ngh6_sendMessage);
}

void Heavy_ChaffVerb::cVar_xU2QLchf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CTRtAvPN, HV_BINOP_MULTIPLY, 0, m, &cBinop_CTRtAvPN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xKOm0zWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MAXP30XF, 0, m, &cDelay_MAXP30XF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fDOsPPEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MAXP30XF, 2, m, &cDelay_MAXP30XF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_STC9ngh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CTRtAvPN, HV_BINOP_MULTIPLY, 1, m, &cBinop_CTRtAvPN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CTRtAvPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_fDOsPPEc_sendMessage);
}

void Heavy_ChaffVerb::cVar_pDpSOC6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_7BNH55aX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_x5sXQR9T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_cEXgc4ss_sendMessage);
}

void Heavy_ChaffVerb::cVar_L392ELO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UsY72AFJ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_6euSnaLM, 0, m, &cIf_6euSnaLM_sendMessage);
}

void Heavy_ChaffVerb::cUnop_gv4W9GBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zr1PSpAC, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_Zr1PSpAC_sendMessage);
}

void Heavy_ChaffVerb::cUnop_zvCFYcll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zr1PSpAC, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_Zr1PSpAC_sendMessage);
}

void Heavy_ChaffVerb::cIf_6euSnaLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_zvCFYcll_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_gv4W9GBT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_UsY72AFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6euSnaLM, 1, m, &cIf_6euSnaLM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1AlPZXO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TxYpHfKD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_TxYpHfKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_iQWA9K8e_sendMessage);
}

void Heavy_ChaffVerb::cDelay_EGNPR0N3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EGNPR0N3, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_S5BtpJM7, 0, m, &cDelay_S5BtpJM7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EGNPR0N3, 0, m, &cDelay_EGNPR0N3_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Hb9zx3Ds, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_S5BtpJM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_S5BtpJM7, m);
  cMsg_aWsKXu2z_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_UYGTeM79_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Q7MiZrQg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_pwagoBsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DHiwTljY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_kCJUpx5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OfC312kS_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EGNPR0N3, 2, m, &cDelay_EGNPR0N3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jTGDyNS2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DHiwTljY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_kCJUpx5R, 0, m, &hTable_kCJUpx5R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iQWA9K8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_pwagoBsj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aWsKXu2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_kCJUpx5R, 0, m, &hTable_kCJUpx5R_sendMessage);
}

void Heavy_ChaffVerb::cCast_jTGDyNS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EGNPR0N3, 0, m, &cDelay_EGNPR0N3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OfC312kS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_S5BtpJM7, 2, m, &cDelay_S5BtpJM7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Q7MiZrQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Hb9zx3Ds, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_JR0nZVB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iYoI5xp5, HV_BINOP_SUBTRACT, 0, m, &cBinop_iYoI5xp5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aNn1SVvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RdC7fN63_sendMessage);
}

void Heavy_ChaffVerb::cSystem_RdC7fN63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BQheJf0L_sendMessage);
}

void Heavy_ChaffVerb::cVar_PMSsThzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_unQvmGsd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_kreCbN1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kreCbN1I, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ovcNM0eC, 0, m, &cDelay_ovcNM0eC_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_oGLyIP6x, 0, m, &sTabread_oGLyIP6x_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ovcNM0eC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ovcNM0eC, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_oGLyIP6x, 0, m, &sTabread_oGLyIP6x_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ovcNM0eC, 0, m, &cDelay_ovcNM0eC_sendMessage);
}

void Heavy_ChaffVerb::sTabread_oGLyIP6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ZUNeRilY, HV_BINOP_SUBTRACT, 0, m, &cBinop_ZUNeRilY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_7G8RH8VK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IZMWLebC, HV_BINOP_MAX, 0, m, &cBinop_IZMWLebC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BQheJf0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7G8RH8VK, HV_BINOP_MULTIPLY, 0, m, &cBinop_7G8RH8VK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iYoI5xp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B0EQEWk0_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_oGLyIP6x, 0, m, &sTabread_oGLyIP6x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PLcrYguT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_CkSphRvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZUNeRilY, HV_BINOP_SUBTRACT, 1, m, &cBinop_ZUNeRilY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ovcNM0eC, 2, m, &cDelay_ovcNM0eC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_unQvmGsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CkSphRvl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_B0EQEWk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kreCbN1I, 0, m, &cDelay_kreCbN1I_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ovcNM0eC, 0, m, &cDelay_ovcNM0eC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Sq5qvo8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_IZMWLebC, HV_BINOP_MAX, 1, m, &cBinop_IZMWLebC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IZMWLebC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iYoI5xp5, HV_BINOP_SUBTRACT, 1, m, &cBinop_iYoI5xp5_sendMessage);
}

void Heavy_ChaffVerb::cCast_PLcrYguT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kreCbN1I, 0, m, &cDelay_kreCbN1I_sendMessage);
}

void Heavy_ChaffVerb::cBinop_K2UVoqvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kreCbN1I, 2, m, &cDelay_kreCbN1I_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZUNeRilY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_K2UVoqvj_sendMessage);
}

void Heavy_ChaffVerb::cCast_XgL7y4FC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PMSsThzv, 0, m, &cVar_PMSsThzv_sendMessage);
  cMsg_aNn1SVvf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JR0nZVB1, 0, m, &cTabhead_JR0nZVB1_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_psc5VoWw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p8tSM0P0_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_p8tSM0P0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9OK1hxp0_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_lTOktlsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f7jnrxZY, HV_BINOP_ADD, 0, m, &cBinop_f7jnrxZY_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_mBuuEEF6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QS7uVPGy_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_QS7uVPGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4zy5UYaK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_ik9KiUqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MFuRtdV5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jjaH4gJw_sendMessage);
}

void Heavy_ChaffVerb::cVar_BQfqAXFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GOAJvMK3, 0, m, &cVar_GOAJvMK3_sendMessage);
}

void Heavy_ChaffVerb::cVar_GOAJvMK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h86OueuU, HV_BINOP_ADD, 0, m, &cBinop_h86OueuU_sendMessage);
}

void Heavy_ChaffVerb::cVar_lkVcmetA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z9Wuz7Fu, HV_BINOP_ADD, 0, m, &cBinop_Z9Wuz7Fu_sendMessage);
}

void Heavy_ChaffVerb::cVar_keztrPAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5L0NQJL0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_gQbbEBAX, 0, m, &cIf_gQbbEBAX_sendMessage);
}

void Heavy_ChaffVerb::cUnop_pjWDcGqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z9Wuz7Fu, HV_BINOP_ADD, 1, m, &cBinop_Z9Wuz7Fu_sendMessage);
}

void Heavy_ChaffVerb::cUnop_XxLN2JYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z9Wuz7Fu, HV_BINOP_ADD, 1, m, &cBinop_Z9Wuz7Fu_sendMessage);
}

void Heavy_ChaffVerb::cIf_gQbbEBAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_XxLN2JYk_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_pjWDcGqw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_5L0NQJL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gQbbEBAX, 1, m, &cIf_gQbbEBAX_sendMessage);
}

void Heavy_ChaffVerb::cVar_kTxmHFNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mUOSY5C0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_vMmQbbqU, 0, m, &cIf_vMmQbbqU_sendMessage);
}

void Heavy_ChaffVerb::cUnop_S57y7ADP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6QuTKWZJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_lIhVQ8lu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6QuTKWZJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_vMmQbbqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_lIhVQ8lu_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_S57y7ADP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_mUOSY5C0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vMmQbbqU, 1, m, &cIf_vMmQbbqU_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_6QuTKWZJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AcdvJeQs, 0, m, &cSlice_AcdvJeQs_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LIexo4MG, 0, m, &cSlice_LIexo4MG_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IWuueMGx_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MkoAs2ef_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_AcdvJeQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_VNobUAt1, 0, m, &cVar_VNobUAt1_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_VNobUAt1, 0, m, &cVar_VNobUAt1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_LIexo4MG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_1E0v02TO, HV_BINOP_NEQ, 1, m, &cBinop_1E0v02TO_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_VNobUAt1, 1, m, &cVar_VNobUAt1_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_1E0v02TO, HV_BINOP_NEQ, 1, m, &cBinop_1E0v02TO_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_VNobUAt1, 1, m, &cVar_VNobUAt1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_VNobUAt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LyqpKw1o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FfGytdZb_sendMessage);
}

void Heavy_ChaffVerb::cIf_tjQoGLW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_26mE32bi_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xquKf5Ps_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_26mE32bi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1E0v02TO, HV_BINOP_NEQ, 1, m, &cBinop_1E0v02TO_sendMessage);
}

void Heavy_ChaffVerb::cCast_xquKf5Ps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VNobUAt1, 0, m, &cVar_VNobUAt1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1E0v02TO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tjQoGLW2, 1, m, &cIf_tjQoGLW2_sendMessage);
}

void Heavy_ChaffVerb::cCast_IWuueMGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1E0v02TO, HV_BINOP_NEQ, 0, m, &cBinop_1E0v02TO_sendMessage);
}

void Heavy_ChaffVerb::cCast_MkoAs2ef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tjQoGLW2, 0, m, &cIf_tjQoGLW2_sendMessage);
}

void Heavy_ChaffVerb::cIf_CVwK3JSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_BQfqAXFO, 0, m, &cVar_BQfqAXFO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_nNOE8Rmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_CVwK3JSV, 0, m, &cIf_CVwK3JSV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_vJg0krm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_CVwK3JSV, 0, m, &cIf_CVwK3JSV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_32OmouW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_CVwK3JSV, 0, m, &cIf_CVwK3JSV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_d54lKCxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ik9KiUqm, 0, m, &cVar_ik9KiUqm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_dD6HUpsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lkVcmetA, 0, m, &cVar_lkVcmetA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ss6myNPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_nNOE8Rmb, 1, m, &cIf_nNOE8Rmb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nz40jdbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_32OmouW4, 1, m, &cIf_32OmouW4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Pd23kr4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_nNOE8Rmb, 1, m, &cIf_nNOE8Rmb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_vJg0krm3, 1, m, &cIf_vJg0krm3_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_32OmouW4, 1, m, &cIf_32OmouW4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_f99Ua9W1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lTOktlsM, 0, m, &cVar_lTOktlsM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CjyGG9zE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_f99Ua9W1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4zy5UYaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ik9KiUqm, 0, m, &cVar_ik9KiUqm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Zr1PSpAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lIOTJJij, HV_BINOP_MULTIPLY, 0, m, &cBinop_lIOTJJij_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cEXgc4ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zr1PSpAC, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_Zr1PSpAC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vjotDcve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_vJg0krm3, 1, m, &cIf_vJg0krm3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Z9Wuz7Fu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RVRRcq4z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nNKcxCvl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_q9K7JYlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4gJVQYYc, 0, m, &cVar_4gJVQYYc_sendMessage);
}

void Heavy_ChaffVerb::cCast_RVRRcq4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q9K7JYlT, HV_BINOP_ADD, 1, m, &cBinop_q9K7JYlT_sendMessage);
}

void Heavy_ChaffVerb::cCast_nNKcxCvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BQfqAXFO, 0, m, &cVar_BQfqAXFO_sendMessage);
}

void Heavy_ChaffVerb::cCast_FfGytdZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_N4Uzjg55_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_LyqpKw1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pd23kr4Q_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_gy5ikwOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FHFZmOYJ, 0, m, &cVar_FHFZmOYJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lIOTJJij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vJg0krm3, 0, m, &cIf_vJg0krm3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CoK6isnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_32OmouW4, 0, m, &cIf_32OmouW4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_93yD7eOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_28xkgDT8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_CoK6isnP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7BNH55aX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_VXSG8MyC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VXSG8MyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_93yD7eOZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_x5sXQR9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pDpSOC6L, 1, m, &cVar_pDpSOC6L_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sWkdVYUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OKQMT6vc, 0, m, &cVar_OKQMT6vc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GOaeReXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xU2QLchf, 0, m, &cVar_xU2QLchf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9OK1hxp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_BQfqAXFO, 0, m, &cVar_BQfqAXFO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_f7jnrxZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JtcYcVq1, HV_BINOP_MULTIPLY, 0, m, &cBinop_JtcYcVq1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JtcYcVq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d54lKCxX, 0, m, &cIf_d54lKCxX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Xd7hQOPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q9K7JYlT, HV_BINOP_ADD, 0, m, &cBinop_q9K7JYlT_sendMessage);
}

void Heavy_ChaffVerb::cCast_jjaH4gJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BQfqAXFO, 0, m, &cVar_BQfqAXFO_sendMessage);
}

void Heavy_ChaffVerb::cCast_MFuRtdV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xd7hQOPd, HV_BINOP_ADD, 1, m, &cBinop_Xd7hQOPd_sendMessage);
}

void Heavy_ChaffVerb::cCast_TxU0NbgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CVwK3JSV, 1, m, &cIf_CVwK3JSV_sendMessage);
}

void Heavy_ChaffVerb::cCast_OAumasf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_psc5VoWw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_TwUPTCf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lTOktlsM, 0, m, &cVar_lTOktlsM_sendMessage);
}

void Heavy_ChaffVerb::cCast_wxukpuHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JtcYcVq1, HV_BINOP_MULTIPLY, 1, m, &cBinop_JtcYcVq1_sendMessage);
}

void Heavy_ChaffVerb::cCast_KmxNCXmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mBuuEEF6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_GsD3Fpdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d54lKCxX, 1, m, &cIf_d54lKCxX_sendMessage);
}

void Heavy_ChaffVerb::cCast_RpG3cMQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lTOktlsM, 0, m, &cVar_lTOktlsM_sendMessage);
}

void Heavy_ChaffVerb::cCast_JkSt1k9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f7jnrxZY, HV_BINOP_ADD, 1, m, &cBinop_f7jnrxZY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jV2Bjrv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xd7hQOPd, HV_BINOP_ADD, 0, m, &cBinop_Xd7hQOPd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_h86OueuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jV2Bjrv4, HV_BINOP_MULTIPLY, 0, m, &cBinop_jV2Bjrv4_sendMessage);
}

void Heavy_ChaffVerb::cCast_9BERUQ6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BQfqAXFO, 0, m, &cVar_BQfqAXFO_sendMessage);
}

void Heavy_ChaffVerb::cCast_ymbjjUXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jV2Bjrv4, HV_BINOP_MULTIPLY, 1, m, &cBinop_jV2Bjrv4_sendMessage);
}

void Heavy_ChaffVerb::cCast_Y0etEuyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BQfqAXFO, 0, m, &cVar_BQfqAXFO_sendMessage);
}

void Heavy_ChaffVerb::cCast_SCyEOrPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h86OueuU, HV_BINOP_ADD, 1, m, &cBinop_h86OueuU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YBbSi8es_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LyqpKw1o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FfGytdZb_sendMessage);
}

void Heavy_ChaffVerb::cReceive_oRVN8Cm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rWVrliwp_sendMessage(_c, 0, m);
  cMsg_5MrJJmeW_sendMessage(_c, 0, m);
  cMsg_IFldoeC5_sendMessage(_c, 0, m);
  cMsg_KdxdNUDI_sendMessage(_c, 0, m);
  cMsg_jeOrtWOX_sendMessage(_c, 0, m);
  cMsg_gAvmoMPb_sendMessage(_c, 0, m);
  cMsg_g2QUpxBb_sendMessage(_c, 0, m);
  cMsg_9yfStTvK_sendMessage(_c, 0, m);
  cMsg_3QFyFfvK_sendMessage(_c, 0, m);
  cMsg_HQ7onNKQ_sendMessage(_c, 0, m);
  cMsg_YvY1vgPM_sendMessage(_c, 0, m);
  cMsg_3eb1Xok9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DzGgnI8S, 0, m, &cVar_DzGgnI8S_sendMessage);
  cMsg_DBlnray8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vjuWVpod, 0, m, &cVar_vjuWVpod_sendMessage);
  cMsg_ysskyK13_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GAEOgI0W, 0, m, &cVar_GAEOgI0W_sendMessage);
  cMsg_MR4HIrKO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cSbz2AVe, 0, m, &cVar_cSbz2AVe_sendMessage);
  cMsg_yH8vbQtS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_98ZFLQWa, 0, m, &cVar_98ZFLQWa_sendMessage);
  cMsg_4vkdTRp0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_OKQMT6vc, 0, m, &cVar_OKQMT6vc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YtI9UFlS, 0, m, &cVar_YtI9UFlS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FHFZmOYJ, 0, m, &cVar_FHFZmOYJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EXzgjIwo, 0, m, &cVar_EXzgjIwo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_S1t03x3k, 0, m, &cVar_S1t03x3k_sendMessage);
  cMsg_Q6lLSRJh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xU2QLchf, 0, m, &cVar_xU2QLchf_sendMessage);
  cMsg_1AlPZXO1_sendMessage(_c, 0, m);
  cSwitchcase_AQ07Wzsg_onMessage(_c, NULL, 0, m, NULL);
  cMsg_9OK1hxp0_sendMessage(_c, 0, m);
  cMsg_YBbSi8es_sendMessage(_c, 0, m);
  cMsg_4zy5UYaK_sendMessage(_c, 0, m);
  cSwitchcase_j4mUZ5kX_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_0xe50CwJ, 0, m, &cVar_0xe50CwJ_sendMessage);
  cMsg_ytJpwzjy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BGNB62t7, 0, m, &cVar_BGNB62t7_sendMessage);
  cMsg_aHuTCYAY_sendMessage(_c, 0, m);
  cMsg_rToy5fIW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_66UNRuIJ, 0, m, &cVar_66UNRuIJ_sendMessage);
  cMsg_DlVoXpom_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_VHNUpcyY, 0, m, &cTabhead_VHNUpcyY_sendMessage);
  cMsg_63dzpwrQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oSioy4RR, 0, m, &cVar_oSioy4RR_sendMessage);
  cMsg_uaWZChKu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1MzJEVP6, 0, m, &cTabhead_1MzJEVP6_sendMessage);
  cMsg_HJf3cDOp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_flBywxs2, 0, m, &cVar_flBywxs2_sendMessage);
  cMsg_rHZdSoS3_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MwQcb610, 0, m, &cTabhead_MwQcb610_sendMessage);
  cMsg_Vbx8dKzW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TvCobsRN, 0, m, &cVar_TvCobsRN_sendMessage);
  cMsg_CdiH7B7V_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_bkqdNuFv, 0, m, &cTabhead_bkqdNuFv_sendMessage);
  cMsg_ZAcd3uka_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_alUUrjTT, 0, m, &cVar_alUUrjTT_sendMessage);
  cMsg_Y46bO6Bw_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_S6dA0o4k, 0, m, &cTabhead_S6dA0o4k_sendMessage);
  cMsg_FwWBWsdJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pPIFiRJX, 0, m, &cVar_pPIFiRJX_sendMessage);
  cMsg_H2I5CIsT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5hqF6Qbl, 0, m, &cTabhead_5hqF6Qbl_sendMessage);
  cMsg_4hHgeszQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Wmo9EFSb, 0, m, &cVar_Wmo9EFSb_sendMessage);
  cMsg_O2YNCM3h_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_iEuHz5ip, 0, m, &cTabhead_iEuHz5ip_sendMessage);
  cMsg_n2oAmHN7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mW0vqLUQ, 0, m, &cVar_mW0vqLUQ_sendMessage);
  cMsg_wTuiB7iN_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_fj1lZdUQ, 0, m, &cTabhead_fj1lZdUQ_sendMessage);
  cMsg_8EW6vDAB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3CK57A1A, 0, m, &cVar_3CK57A1A_sendMessage);
  cMsg_9kcrLNps_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Gwqtjw7X, 0, m, &cTabhead_Gwqtjw7X_sendMessage);
  cMsg_JtQ9aevW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4xZCBs1H, 0, m, &cVar_4xZCBs1H_sendMessage);
  cMsg_l2HJnGSz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_jwI9Xa6u, 0, m, &cTabhead_jwI9Xa6u_sendMessage);
  cMsg_Sq5qvo8x_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PMSsThzv, 0, m, &cVar_PMSsThzv_sendMessage);
  cMsg_aNn1SVvf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JR0nZVB1, 0, m, &cTabhead_JR0nZVB1_sendMessage);
}

void Heavy_ChaffVerb::cReceive_rx8N8NAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_sWkdVYUe_sendMessage);
}

void Heavy_ChaffVerb::cReceive_jrZMpkW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kTxmHFNq, 0, m, &cVar_kTxmHFNq_sendMessage);
}

void Heavy_ChaffVerb::cReceive_1udgLxMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_L392ELO7, 0, m, &cVar_L392ELO7_sendMessage);
}

void Heavy_ChaffVerb::cReceive_N8oRy1d1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lIOTJJij, HV_BINOP_MULTIPLY, 1, m, &cBinop_lIOTJJij_sendMessage);
}

void Heavy_ChaffVerb::cReceive_UmxbtSMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SCyEOrPw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y0etEuyF_sendMessage);
}

void Heavy_ChaffVerb::cReceive_GqyccCos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ymbjjUXJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9BERUQ6T_sendMessage);
}

void Heavy_ChaffVerb::cReceive_TAihuQ2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lkVcmetA, 0, m, &cVar_lkVcmetA_sendMessage);
}

void Heavy_ChaffVerb::cReceive_vYhXSovW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dD6HUpsi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_keztrPAf, 0, m, &cVar_keztrPAf_sendMessage);
}

void Heavy_ChaffVerb::cReceive_SbVJHtzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_GOaeReXA_sendMessage);
}

void Heavy_ChaffVerb::cReceive_LfjHtJyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JkSt1k9a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RpG3cMQR_sendMessage);
}

void Heavy_ChaffVerb::cReceive_VE4Ch99B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wxukpuHA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TwUPTCf9_sendMessage);
}

void Heavy_ChaffVerb::cReceive_XHEabZlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GsD3Fpdn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KmxNCXmL_sendMessage);
}

void Heavy_ChaffVerb::cReceive_O7sTwoqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_alBIFmt2, m);
}

void Heavy_ChaffVerb::cReceive_CoAVDHp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nZPc1cJP, m);
}

void Heavy_ChaffVerb::cReceive_kSJEvwUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YtI9UFlS, 0, m, &cVar_YtI9UFlS_sendMessage);
}

void Heavy_ChaffVerb::cReceive_GKaMurlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_gy5ikwOB_sendMessage);
}

void Heavy_ChaffVerb::cReceive_7w5DpbRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zbw6nRua, 0, m, &cVar_zbw6nRua_sendMessage);
}

void Heavy_ChaffVerb::cReceive_GYtnhZZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e4HziIjw, 0, m, &cVar_e4HziIjw_sendMessage);
}

void Heavy_ChaffVerb::cReceive_oiXnj4Bw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_98ZFLQWa, 0, m, &cVar_98ZFLQWa_sendMessage);
}

void Heavy_ChaffVerb::cReceive_iHeah1DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lBraqtum, m);
}

void Heavy_ChaffVerb::cReceive_7aQ6oG4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Xtzp7OS4, m);
}

void Heavy_ChaffVerb::cReceive_gUtIJKth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7G8RH8VK, HV_BINOP_MULTIPLY, 1, m, &cBinop_7G8RH8VK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XgL7y4FC_sendMessage);
}

void Heavy_ChaffVerb::cReceive_mkrbxsGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TxU0NbgE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OAumasf5_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_ERdIvyGD, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_xfuVcpxL, VOf(Bf4));
    __hv_line_f(&sLine_dy9qa5o0, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_qZ6meuwX, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_7VobTcI1, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_S9IbsNIL, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_au2mqq4Z, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_rAMXp1EY, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_HsMZ05sY, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_SAPMiBJB, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_Pw6XGGzx, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Bk38OOll, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_WMfXXAGu, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_flSoxKp2, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_tyQjS7ka, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_rTjauolH, VIf(I0));
    __hv_varread_f(&sVarf_m2D7eUJt, VOf(Bf2));
    __hv_rpole_f(&sRPole_R5MJW1ot, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_Vb64x7LZ, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_wgDBY61G, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_lBraqtum, VOf(Bf1));
    __hv_tabread_f(&sTabread_oGLyIP6x, VOf(Bf5));
    __hv_varread_f(&sVarf_Xtzp7OS4, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_Hb9zx3Ds, VIf(Bf9));
    __hv_varread_f(&sVarf_nZPc1cJP, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_guWyVg9B, VOf(Bf9));
    __hv_varread_f(&sVarf_MgMfgY4V, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Sj6KzPbl, VOf(Bf2));
    __hv_rpole_f(&sRPole_yLhijXIR, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_gcmhCJGh, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_3U3TA50p, VOf(Bf2));
    __hv_tabread_f(&sTabread_MkzWsSW2, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_vMdXOTR5, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_HDOMTeYp, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_RnN0W5Qf, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_VOnK3mhv, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_haIi5phZ, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_zd4xJu88, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_X0zvk12g, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_O41y9N0s, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_Y0Yi1BAy, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_92FFn8B7, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_oAtZ59Fu, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_n6s9zB6H, VOf(Bf9));
    __hv_varread_f(&sVarf_zosRLRdY, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_9Ase1ZHW, VOf(Bf3));
    __hv_rpole_f(&sRPole_kB7pyp57, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_vEDhi6Rh, VOf(Bf3));
    __hv_varread_f(&sVarf_o59suLKx, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_ThuXaZPy, VOf(Bf12));
    __hv_rpole_f(&sRPole_hw2MmEKt, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_N6lRVyoH, VOf(Bf12));
    __hv_varread_f(&sVarf_CwFhWOxb, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_XwL3bbJ5, VOf(Bf11));
    __hv_rpole_f(&sRPole_DvTzBPfI, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_5ueQZyas, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_ZDs6rfmz, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_1PE4jJf8, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_aUIH03YJ, VIf(Bf11));
    __hv_line_f(&sLine_OuJ1r92g, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_alBIFmt2, VOf(Bf2));
    __hv_mul_f(VIf(I0), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf13), VIf(Bf2), VOf(Bf13));
    __hv_add_f(VIf(Bf13), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
